あうt #KJ*13 会
あうt #KJ*13 合
あうt #KJ*11 遭
あうt #KJ*7 逢
あうt #KJ*5 會
あうt #KJ*5 翕
あうt #KJ*5 覯
あうt #KJ*5 覿
あうt #KJ*5 逅
あうt #KJ*5 遘
あうt #KJ*5 邂
あえぐt #KJ*5 喘
あおいt #KJ*13 青
あおいt #KJ*7 蒼
あおぐt #KJ*11 仰
あおぐろいt #KJ*5 黝
あおりt #KJ*7 煽
あおるt #KJ*7 煽
あおるt #KJ*5 呷
あかいt #KJ*13 赤
あかいt #KJ*7 赫
あかすt #KJ*13 明
あかすt #KJ*11 飽
あからむt #KJ*13 明
あからむt #KJ*13 赤
あからめるt #KJ*13 赤
あからめるt #KJ*5 赧
あかりt #KJ*13 明
あかりt #KJ*11 燈
あかるいt #KJ*13 明
あかるむt #KJ*13 明
あがなうt #KJ*5 贖
あがるt #KJ*13 上
あがるt #KJ*13 挙
あがるt #KJ*11 揚
あがるt #KJ*7 昂
あがるt #KJ*5 擧
あがるt #KJ*5 舉
あがるt #KJ*5 驤
あきたりないt #KJ*5 慊
あきたりないt #KJ*5 歉
あきたりるt #KJ*5 慊
あきないt #KJ*5 賈
あきなうt #KJ*13 商
あきなうt #KJ*5 估
あきなうt #KJ*5 賈
あきらかt #KJ*13 明
あきらかt #KJ*13 昭
あきらかt #KJ*7 叡
あきらかt #KJ*7 晃
あきらかt #KJ*7 爽
あきらかt #KJ*7 瞭
あきらかt #KJ*5 冏
あきらかt #KJ*5 昿
あきらかt #KJ*5 晄
あきらかt #KJ*5 晢
あきらかt #KJ*5 晤
あきらかt #KJ*5 晰
あきらかt #KJ*5 暸
あきらかt #KJ*5 曠
あきらかt #KJ*5 朖
あきらかt #KJ*5 杲
あきらかt #KJ*5 炯
あきらかt #KJ*5 炳
あきらかt #KJ*5 烱
あきらかt #KJ*5 煥
あきらかt #KJ*5 睿
あきらかt #KJ*5 顯
あきらめるt #KJ*7 諦
あきるt #KJ*11 飽
あきるt #KJ*7 厭
あきるt #KJ*5 飫
あきれるt #KJ*7 呆
あきれるt #KJ*5 惘
あくt #KJ*13 明
あくt #KJ*13 空
あくt #KJ*13 開
あくるt #KJ*13 明
あけるt #KJ*13 明
あけるt #KJ*13 空
あけるt #KJ*13 開
あげるt #KJ*13 上
あげるt #KJ*13 挙
あげるt #KJ*11 揚
あげるt #KJ*5 扛
あげるt #KJ*5 擧
あげるt #KJ*5 稱
あげるt #KJ*5 翹
あげるt #KJ*5 舉
あこがれるt #KJ*7 憧
あさいt #KJ*13 浅
あさいt #KJ*5 淺
あざけるt #KJ*5 嘲
あざなうt #KJ*5 糺
あざむくt #KJ*11 欺
あざむくt #KJ*5 紿
あざむくt #KJ*5 詒
あざむくt #KJ*5 誣
あざむくt #KJ*5 謾
あざやかt #KJ*11 鮮
あじわうt #KJ*13 味
あずかるt #KJ*13 預
あずかるt #KJ*5 與
あずけるt #KJ*13 預
あせるt #KJ*11 焦
あせるt #KJ*5 褪
あそびt #KJ*13 遊
あそびt #KJ*5 游
あそぶt #KJ*13 遊
あそぶt #KJ*5 敖
あそぶt #KJ*5 游
あそぶt #KJ*5 遨
あたえるt #KJ*11 与
あたえるt #KJ*5 與
あたかもt #KJ*7 宛
あたかもt #KJ*7 恰
あたたかt #KJ*13 暖
あたたかt #KJ*13 温
あたたかt #KJ*5 煖
あたたかいt #KJ*13 暖
あたたかいt #KJ*13 温
あたたかいt #KJ*5 暄
あたたかいt #KJ*5 燠
あたたまるt #KJ*13 暖
あたたまるt #KJ*13 温
あたためるt #KJ*13 暖
あたためるt #KJ*13 温
あたためるt #KJ*5 煖
あたためるt #KJ*5 煦
あたらしいt #KJ*13 新
あたりt #KJ*5 邉
あたりt #KJ*5 邊
あたるt #KJ*13 当
あたるt #KJ*5 當
あついt #KJ*13 厚
あついt #KJ*13 暑
あついt #KJ*13 熱
あついt #KJ*11 篤
あついt #KJ*7 敦
あついt #KJ*7 淳
あついt #KJ*7 渥
あついt #KJ*5 亶
あついt #KJ*5 腆
あつかうt #KJ*11 扱
あつまるt #KJ*13 集
あつまるt #KJ*5 攅
あつまるt #KJ*5 會
あつまるt #KJ*5 聚
あつまるt #KJ*5 萃
あつまるt #KJ*5 輳
あつめるt #KJ*13 集
あつめるt #KJ*7 纂
あつめるt #KJ*7 輯
あつめるt #KJ*7 鍾
あつめるt #KJ*7 鳩
あつらえt #KJ*5 誂
あつらえるt #KJ*5 誂
あてるt #KJ*13 当
あてるt #KJ*11 充
あてるt #KJ*7 宛
あてるt #KJ*5 當
あなどるt #KJ*11 侮
あなどるt #KJ*5 傲
あなどるt #KJ*5 狎
あなどるt #KJ*5 謾
あばくt #KJ*13 暴
あばくt #KJ*5 發
あばくt #KJ*5 訐
あばれるt #KJ*13 暴
あびせるt #KJ*13 浴
あびるt #KJ*13 浴
あふれるt #KJ*7 溢
あぶないt #KJ*13 危
あぶるt #KJ*5 炙
あぶるt #KJ*5 炮
あぶるt #KJ*5 焙
あぶるt #KJ*5 煬
あぶるt #KJ*5 熹
あまいt #KJ*11 甘
あまえるt #KJ*11 甘
あますt #KJ*13 余
あますt #KJ*5 餘
あまつさえt #KJ*5 剩
あまねしt #KJ*5 徇
あまねしt #KJ*5 洽
あまねしt #KJ*5 溥
あまやかすt #KJ*11 甘
あまりt #KJ*7 羨
あまりt #KJ*5 剩
あまりt #KJ*5 衍
あまりt #KJ*5 贏
あまるt #KJ*13 余
あまるt #KJ*5 剩
あまるt #KJ*5 餘
あむt #KJ*13 編
あむt #KJ*5 辮
あやういt #KJ*13 危
あやういt #KJ*7 殆
あやしいt #KJ*11 怪
あやしいt #KJ*5 恠
あやしいt #KJ*5 竒
あやしむt #KJ*11 怪
あやしむt #KJ*5 恠
あやつるt #KJ*13 操
あやぶむt #KJ*13 危
あやまちt #KJ*13 過
あやまつt #KJ*13 過
あやまるt #KJ*13 誤
あやまるt #KJ*13 謝
あやまるt #KJ*7 謬
あやまるt #KJ*5 愆
あやまるt #KJ*5 繆
あやまるt #KJ*5 訛
あやまるt #KJ*5 譌
あゆむt #KJ*13 歩
あらいt #KJ*11 粗
あらいt #KJ*11 荒
あらいt #KJ*5 沽
あらいt #KJ*5 糲
あらいt #KJ*5 麁
あらうt #KJ*13 洗
あらうt #KJ*5 沐
あらうt #KJ*5 洒
あらうt #KJ*5 浣
あらうt #KJ*5 滌
あらうt #KJ*5 澡
あらうt #KJ*5 澣
あらかじめt #KJ*13 予
あらかじめt #KJ*5 豫
あらすt #KJ*11 荒
あらそうt #KJ*13 争
あらそうt #KJ*5 爭
あらそうt #KJ*5 諍
あらたt #KJ*13 新
あらたまるt #KJ*13 改
あらためるt #KJ*13 改
あらためるt #KJ*5 悛
あらわすt #KJ*13 現
あらわすt #KJ*13 著
あらわすt #KJ*13 表
あらわすt #KJ*5 旌
あらわれるt #KJ*13 現
あらわれるt #KJ*13 表
あるt #KJ*13 在
あるt #KJ*13 有
あるt #KJ*7 或
あるいはt #KJ*7 或
あるくt #KJ*13 歩
あれるt #KJ*11 荒
あわいt #KJ*11 淡
あわいt #KJ*5 澹
あわすt #KJ*13 合
あわせるt #KJ*13 合
あわせるt #KJ*11 併
あわせるt #KJ*5 勠
あわせるt #KJ*5 并
あわせるt #KJ*5 恊
あわただしいt #KJ*11 慌
あわただしいt #KJ*5 遽
あわてるt #KJ*11 慌
あわれt #KJ*11 哀
あわれみt #KJ*7 憐
あわれむt #KJ*11 哀
あわれむt #KJ*7 憐
あわれむt #KJ*5 恤
あわれむt #KJ*5 愍
あわれむt #KJ*5 憫
あわれむt #KJ*5 矜
あわれむt #KJ*5 閔
いうt #KJ*13 言
いうt #KJ*7 云
いうt #KJ*7 謂
いえどもt #KJ*5 雖
いえるt #KJ*5 瘉
いかすt #KJ*13 生
いかでt #KJ*5 怎
いかでかt #KJ*5 爭
いかめしいt #KJ*5 儼
いからすt #KJ*5 瞋
いかりt #KJ*5 忿
いかりt #KJ*5 慍
いかるt #KJ*11 怒
いかるt #KJ*5 嗔
いかるt #KJ*5 恚
いかるt #KJ*5 慍
いかるt #KJ*5 瞋
いがむt #KJ*5 啀
いきおいt #KJ*13 勢
いきどおるt #KJ*11 憤
いきるt #KJ*13 生
いくt #KJ*13 行
いくt #KJ*5 徃
いけるt #KJ*13 生
いこいt #KJ*11 憩
いこいt #KJ*5 憇
いこうt #KJ*11 憩
いこうt #KJ*5 憇
いさかうt #KJ*5 諍
いさぎよいt #KJ*13 潔
いささかt #KJ*7 些
いささかt #KJ*5 聊
いさむt #KJ*13 勇
いさめt #KJ*7 諌
いさめt #KJ*5 諫
いさめるt #KJ*7 諌
いさめるt #KJ*5 諍
いさめるt #KJ*5 諫
いさりt #KJ*13 漁
いずくんぞt #KJ*5 惡
いずくんぞt #KJ*5 焉
いずれt #KJ*5 孰
いそがしいt #KJ*11 忙
いそがしいt #KJ*5 匆
いそぐt #KJ*13 急
いたいt #KJ*13 痛
いたすt #KJ*11 致
いたすt #KJ*5 效
いただくt #KJ*13 頂
いただくt #KJ*7 戴
いたむt #KJ*13 傷
いたむt #KJ*13 痛
いたむt #KJ*11 悼
いたむt #KJ*5 怛
いたむt #KJ*5 恫
いたむt #KJ*5 悵
いたむt #KJ*5 悽
いたむt #KJ*5 惻
いたむt #KJ*5 愴
いたむt #KJ*5 慘
いたむt #KJ*5 疼
いためるt #KJ*13 傷
いためるt #KJ*13 痛
いためるt #KJ*5 炒
いたるt #KJ*13 至
いたるt #KJ*7 詣
いたるt #KJ*5 摯
いたるt #KJ*5 臻
いたわるt #KJ*13 労
いたわるt #KJ*5 勞
いだくt #KJ*11 抱
いだくt #KJ*5 懷
いちじるしいt #KJ*13 著
いつくしむt #KJ*11 慈
いつつt #KJ*13 五
いつわりt #KJ*5 譎
いつわるt #KJ*11 偽
いつわるt #KJ*5 佯
いつわるt #KJ*5 僞
いつわるt #KJ*5 詭
いつわるt #KJ*5 譎
いとうt #KJ*7 厭
いとけないt #KJ*5 穉
いとなむt #KJ*13 営
いとなむt #KJ*5 營
いどむt #KJ*9 挑
いどむt #KJ*5 誂
いななくt #KJ*5 嘶
いのるt #KJ*11 祈
いのるt #KJ*7 祷
いぶかるt #KJ*5 訝
いましめるt #KJ*11 戒
いましめるt #KJ*5 敕
いましめるt #KJ*5 箴
いましめるt #KJ*5 誡
いましめるt #KJ*5 飭
いまだt #KJ*13 未
いまわしいt #KJ*11 忌
いむt #KJ*11 忌
いむt #KJ*5 諱
いやしいt #KJ*11 卑
いやしいt #KJ*7 賎
いやしいt #KJ*5 俚
いやしいt #KJ*5 賤
いやしいt #KJ*5 鄙
いやしいt #KJ*5 陋
いやしくもt #KJ*5 苟
いやしむt #KJ*11 卑
いやしめるt #KJ*11 卑
いやすt #KJ*5 醫
いらだつt #KJ*7 苛
いるt #KJ*13 入
いるt #KJ*13 射
いるt #KJ*13 居
いるt #KJ*13 要
いるt #KJ*11 鋳
いるt #KJ*7 煎
いるt #KJ*5 炒
いるt #KJ*5 熬
いるt #KJ*5 鑄
いれるt #KJ*13 入
いろどるt #KJ*11 彩
いわうt #KJ*13 祝
いわくt #KJ*5 曰
いわんやt #KJ*11 況
いわんやt #KJ*5 况
ういt #KJ*11 憂
うえるt #KJ*13 植
うえるt #KJ*11 飢
うえるt #KJ*7 蒔
うえるt #KJ*5 藝
うえるt #KJ*5 餒
うえるt #KJ*5 饉
うえるt #KJ*5 饑
うかがいt #KJ*7 窺
うかがうt #KJ*11 伺
うかがうt #KJ*7 窺
うかがうt #KJ*7 覗
うかがうt #KJ*7 諜
うかがうt #KJ*5 俔
うかがうt #KJ*5 覘
うかがうt #KJ*5 遉
うかがうt #KJ*5 闖
うかぶt #KJ*11 浮
うかぶt #KJ*5 泛
うかべるt #KJ*11 浮
うかるt #KJ*13 受
うかれるt #KJ*11 浮
うがつt #KJ*7 穿
うがつt #KJ*5 鑿
うくt #KJ*11 浮
うけたまわるt #KJ*13 承
うけるt #KJ*13 受
うけるt #KJ*11 請
うけるt #KJ*7 饗
うごかすt #KJ*13 動
うごかすt #KJ*5 撼
うごくt #KJ*13 動
うごくt #KJ*5 盪
うごくt #KJ*5 蘯
うごくt #KJ*5 蹌
うごめくt #KJ*5 蠢
うしなうt #KJ*13 失
うしろt #KJ*13 後
うすいt #KJ*11 薄
うすいt #KJ*5 漓
うすいt #KJ*5 菲
うすまるt #KJ*11 薄
うすめるt #KJ*11 薄
うすらぐt #KJ*11 薄
うすれるt #KJ*11 薄
うずくt #KJ*5 疼
うずくまるt #KJ*5 踞
うずたかいt #KJ*7 堆
うずめるt #KJ*7 填
うそぶくt #KJ*5 嘯
うたうt #KJ*13 唱
うたうt #KJ*13 歌
うたうt #KJ*11 謡
うたうt #KJ*5 咏
うたうt #KJ*5 嘔
うたうt #KJ*5 謌
うたうt #KJ*5 謠
うたうt #KJ*5 謳
うたがうt #KJ*13 疑
うったえるt #KJ*11 訴
うったえるt #KJ*5 愬
うったえるt #KJ*5 諍
うつt #KJ*13 打
うつt #KJ*13 討
うつt #KJ*11 撃
うつt #KJ*5 抃
うつt #KJ*5 拊
うつt #KJ*5 挌
うつt #KJ*5 搏
うつt #KJ*5 擣
うつt #KJ*5 毆
うつくしいt #KJ*13 美
うつくしいt #KJ*5 倩
うつくしいt #KJ*5 妍
うつくしいt #KJ*5 婉
うつすt #KJ*13 写
うつすt #KJ*13 映
うつすt #KJ*13 移
うつすt #KJ*5 冩
うつすt #KJ*5 寫
うつすt #KJ*5 徙
うつすt #KJ*5 暎
うつるt #KJ*13 写
うつるt #KJ*13 映
うつるt #KJ*13 移
うつるt #KJ*5 冩
うつるt #KJ*5 寫
うつるt #KJ*5 暎
うといt #KJ*11 疎
うといt #KJ*5 踈
うとむt #KJ*11 疎
うとむt #KJ*5 踈
うながすt #KJ*11 促
うなずくt #KJ*5 頷
うなづくt #KJ*5 頷
うなりt #KJ*5 唸
うなるt #KJ*5 唸
うばうt #KJ*11 奪
うばうt #KJ*5 簒
うばうt #KJ*5 褫
うまるt #KJ*11 埋
うまれるt #KJ*13 生
うまれるt #KJ*13 産
うむt #KJ*13 生
うむt #KJ*13 産
うむt #KJ*7 倦
うむt #KJ*5 孳
うめるt #KJ*11 埋
うもれるt #KJ*11 埋
うやうやしいt #KJ*11 恭
うやまうt #KJ*13 敬
うらないt #KJ*11 占
うらないt #KJ*7 卜
うらなうt #KJ*11 占
うらなうt #KJ*7 卜
うらなうt #KJ*5 筮
うらむt #KJ*11 恨
うらむt #KJ*7 怨
うらむt #KJ*5 怏
うらむt #KJ*5 悵
うらむt #KJ*5 惆
うらむt #KJ*5 慊
うらむt #KJ*5 慍
うらめしいt #KJ*11 恨
うらやむt #KJ*7 羨
うるt #KJ*13 売
うるt #KJ*13 得
うるt #KJ*5 售
うるt #KJ*5 沽
うるt #KJ*5 賈
うるt #KJ*5 賣
うるおいt #KJ*7 濡
うるおいt #KJ*5 澤
うるおいt #KJ*5 霑
うるおうt #KJ*11 潤
うるおうt #KJ*7 濡
うるおうt #KJ*5 沾
うるおうt #KJ*5 濕
うるおうt #KJ*5 霑
うるおすt #KJ*11 潤
うるおすt #KJ*7 濡
うるおすt #KJ*5 沾
うるおすt #KJ*5 洽
うるむt #KJ*11 潤
うるわしいt #KJ*11 麗
うれいt #KJ*11 愁
うれいt #KJ*11 憂
うれいt #KJ*11 騒
うれいt #KJ*5 騷
うれえるt #KJ*11 愁
うれえるt #KJ*11 憂
うれえるt #KJ*7 戚
うれえるt #KJ*5 恤
うれえるt #KJ*5 悄
うれえるt #KJ*5 悒
うれえるt #KJ*5 憫
うれしいt #KJ*7 嬉
うれるt #KJ*13 売
うれるt #KJ*13 熟
うれるt #KJ*5 賣
うわるt #KJ*13 植
えがくt #KJ*13 画
えがくt #KJ*11 描
えがくt #KJ*5 畫
えがくt #KJ*5 繪
えぐるt #KJ*5 刔
えぐるt #KJ*5 刳
えぐるt #KJ*5 抉
えむt #KJ*13 笑
えらいt #KJ*11 偉
えらぶt #KJ*13 選
えらぶt #KJ*7 撰
えらぶt #KJ*5 掏
えらぶt #KJ*5 揀
えらぶt #KJ*5 擇
えらぶt #KJ*5 柬
えるt #KJ*13 得
えるt #KJ*11 獲
えるt #KJ*5 鐫
おいてt #KJ*7 於
おいてt #KJ*5 于
おいぼれるt #KJ*5 耄
おいるt #KJ*13 老
おいるt #KJ*5 耆
おうt #KJ*13 生
おうt #KJ*13 負
おうt #KJ*13 追
おうt #KJ*5 梍
おうt #KJ*5 趁
おえるt #KJ*13 終
おえるt #KJ*5 訖
おおいt #KJ*13 多
おおいt #KJ*7 蔽
おおいt #KJ*5 夛
おおいt #KJ*5 稠
おおいにt #KJ*13 大
おおうt #KJ*11 冒
おおうt #KJ*11 覆
おおうt #KJ*7 奄
おおうt #KJ*7 庇
おおうt #KJ*7 掩
おおうt #KJ*7 蓋
おおうt #KJ*7 蔽
おおうt #KJ*5 冐
おおうt #KJ*5 盍
おおうt #KJ*5 盖
おおうt #KJ*5 葢
おおきいt #KJ*13 大
おおきいt #KJ*7 碩
おおきいt #KJ*5 丕
おおきいt #KJ*5 傀
おおきいt #KJ*5 厖
おおせt #KJ*11 仰
おおむねt #KJ*11 概
おかすt #KJ*13 犯
おかすt #KJ*11 侵
おかすt #KJ*11 冒
おかすt #KJ*5 冐
おかすt #KJ*5 奸
おがむt #KJ*13 拝
おがむt #KJ*5 拜
おきるt #KJ*13 起
おぎなうt #KJ*13 補
おぎなうt #KJ*5 裨
おくt #KJ*13 置
おくt #KJ*5 擱
おくt #KJ*5 處
おくらすt #KJ*11 遅
おくらすt #KJ*5 遲
おくるt #KJ*13 送
おくるt #KJ*11 贈
おくるt #KJ*5 歸
おくるt #KJ*5 皈
おくるt #KJ*5 貽
おくるt #KJ*5 餽
おくるt #KJ*5 饋
おくれるt #KJ*13 後
おくれるt #KJ*11 遅
おくれるt #KJ*5 遲
おけるt #KJ*7 於
おこすt #KJ*13 興
おこすt #KJ*13 起
おこたるt #KJ*11 怠
おこたるt #KJ*5 嬾
おこたるt #KJ*5 懈
おこたるt #KJ*5 懶
おこなうt #KJ*13 行
おこるt #KJ*13 興
おこるt #KJ*13 起
おこるt #KJ*11 怒
おこるt #KJ*5 發
おごそかt #KJ*13 厳
おごそかt #KJ*11 荘
おごそかt #KJ*5 儼
おごそかt #KJ*5 嚴
おごそかt #KJ*5 莊
おごるt #KJ*7 汰
おごるt #KJ*5 侈
おごるt #KJ*5 倨
おごるt #KJ*5 傲
おごるt #KJ*5 僣
おごるt #KJ*5 僭
おごるt #KJ*5 夸
おごるt #KJ*5 奢
おごるt #KJ*5 敖
おごるt #KJ*5 驕
おさえるt #KJ*11 抑
おさえるt #KJ*11 押
おさえるt #KJ*5 壓
おさえるt #KJ*5 扼
おさえるt #KJ*5 熨
おさないt #KJ*13 幼
おさないt #KJ*5 孺
おさないt #KJ*5 穉
おさまるt #KJ*13 修
おさまるt #KJ*13 収
おさまるt #KJ*13 治
おさまるt #KJ*13 納
おさまるt #KJ*5 收
おさめるt #KJ*13 修
おさめるt #KJ*13 収
おさめるt #KJ*13 治
おさめるt #KJ*13 納
おさめるt #KJ*5 乂
おさめるt #KJ*5 撥
おさめるt #KJ*5 收
おさめるt #KJ*5 斂
おさめるt #KJ*5 爲
おさめるt #KJ*5 畧
おさめるt #KJ*5 脩
おさめるt #KJ*5 艾
おさめるt #KJ*5 藏
おしいt #KJ*11 惜
おしえるt #KJ*13 教
おしえるt #KJ*5 誨
おしむt #KJ*11 惜
おしむt #KJ*5 吝
おしむt #KJ*5 嗇
おしむt #KJ*5 慳
おすt #KJ*13 推
おすt #KJ*11 押
おすt #KJ*7 捺
おすt #KJ*5 擠
おそいt #KJ*11 遅
おそいt #KJ*5 晏
おそいt #KJ*5 遲
おそうt #KJ*11 襲
おそれt #KJ*11 虞
おそれるt #KJ*11 恐
おそれるt #KJ*7 兇
おそれるt #KJ*7 畏
おそれるt #KJ*5 兢
おそれるt #KJ*5 怕
おそれるt #KJ*5 恟
おそれるt #KJ*5 悚
おそれるt #KJ*5 惧
おそれるt #KJ*5 惴
おそれるt #KJ*5 惶
おそれるt #KJ*5 慄
おそれるt #KJ*5 慴
おそれるt #KJ*5 懼
おそれるt #KJ*5 懾
おそれるt #KJ*5 瞿
おそれるt #KJ*5 竦
おそろしいt #KJ*11 恐
おそわるt #KJ*13 教
おだてるt #KJ*7 煽
おだやかt #KJ*11 穏
おだやかt #KJ*5 穩
おちいるt #KJ*11 陥
おちいるt #KJ*5 陷
おちるt #KJ*13 落
おちるt #KJ*5 墮
おちるt #KJ*5 殞
おちるt #KJ*5 隕
おとしいれるt #KJ*11 陥
おとしいれるt #KJ*5 陷
おとしめるt #KJ*5 貶
おとすt #KJ*13 落
おとすt #KJ*5 貶
おとずれるt #KJ*13 訪
おとるt #KJ*11 劣
おとろえるt #KJ*11 衰
おどかすt #KJ*11 威
おどかすt #KJ*11 脅
おどすt #KJ*11 嚇
おどすt #KJ*11 威
おどすt #KJ*11 脅
おどすt #KJ*5 縅
おどりt #KJ*11 踊
おどりt #KJ*5 踴
おどるt #KJ*11 踊
おどるt #KJ*11 躍
おどるt #KJ*5 踴
おどろかすt #KJ*11 驚
おどろかすt #KJ*5 駭
おどろくt #KJ*11 驚
おどろくt #KJ*5 咢
おどろくt #KJ*5 愕
おどろくt #KJ*5 駭
おなじt #KJ*13 同
おののくt #KJ*5 慄
おののくt #KJ*5 戰
おびえるt #KJ*7 怯
おびただしいt #KJ*5 夥
おびやかすt #KJ*11 脅
おびやかすt #KJ*7 劫
おびやかすt #KJ*5 刧
おびやかすt #KJ*5 剽
おびるt #KJ*13 帯
おびるt #KJ*5 佩
おぼえるt #KJ*13 覚
おぼえるt #KJ*5 覺
おぼれるt #KJ*7 溺
おぼれるt #KJ*5 沒
おぼれるt #KJ*5 湎
おもいt #KJ*13 思
おもいt #KJ*13 重
おもうt #KJ*13 思
おもうt #KJ*7 惟
おもうt #KJ*7 謂
おもうt #KJ*5 懷
おもうにt #KJ*7 惟
おもねるt #KJ*7 阿
おもねるt #KJ*5 佞
おもねるt #KJ*5 侫
おもむきt #KJ*11 趣
おもむくt #KJ*11 赴
おもむくt #KJ*7 趨
およぐt #KJ*13 泳
およぐt #KJ*5 泅
およぐt #KJ*5 游
およびt #KJ*11 及
およぶt #KJ*11 及
およぶt #KJ*5 曁
およぼすt #KJ*11 及
おりるt #KJ*13 下
おりるt #KJ*13 降
おるt #KJ*13 折
おるt #KJ*13 織
おるt #KJ*5 處
おれるt #KJ*13 折
おろかt #KJ*11 愚
おろかt #KJ*7 魯
おろかt #KJ*5 癡
おろすt #KJ*13 下
おろすt #KJ*13 降
おろすt #KJ*11 卸
おわりt #KJ*13 終
おわるt #KJ*13 終
おわるt #KJ*7 畢
おわるt #KJ*7 竣
おわるt #KJ*5 卆
おわるt #KJ*5 竟
おわるt #KJ*5 訖
かうt #KJ*13 交
かうt #KJ*13 買
かうt #KJ*13 飼
かうt #KJ*5 賈
かえすt #KJ*13 帰
かえすt #KJ*13 返
かえすt #KJ*5 孵
かえすt #KJ*5 歸
かえすt #KJ*5 皈
かえってt #KJ*5 卻
かえりみるt #KJ*13 省
かえりみるt #KJ*11 顧
かえりみるt #KJ*5 眄
かえりみるt #KJ*5 眷
かえるt #KJ*13 代
かえるt #KJ*13 変
かえるt #KJ*13 帰
かえるt #KJ*13 返
かえるt #KJ*11 換
かえるt #KJ*11 替
かえるt #KJ*5 囘
かえるt #KJ*5 歸
かえるt #KJ*5 皈
かえるt #KJ*5 變
かおりt #KJ*11 香
かおりt #KJ*7 馨
かおりt #KJ*5 芬
かおりt #KJ*5 馥
かおるt #KJ*11 薫
かおるt #KJ*11 香
かおるt #KJ*7 馨
かおるt #KJ*5 馥
かかえるt #KJ*11 抱
かかげるt #KJ*11 掲
かかるt #KJ*13 係
かかるt #KJ*11 懸
かかるt #KJ*11 掛
かかるt #KJ*11 架
かかるt #KJ*5 罹
かかわるt #KJ*5 關
かがむt #KJ*5 傴
かがむt #KJ*5 僂
かがやくt #KJ*11 輝
かがやくt #KJ*7 耀
かがやくt #KJ*7 赫
かがやくt #KJ*5 暉
かがやくt #KJ*5 曄
かがやくt #KJ*5 焜
かがやくt #KJ*5 煌
かがやくt #KJ*5 燿
かぎりt #KJ*13 限
かぎるt #KJ*13 限
かぎるt #KJ*5 畫
かくt #KJ*13 書
かくt #KJ*13 欠
かくt #KJ*7 掻
かくt #KJ*7 斯
かくt #KJ*5 爬
かくt #KJ*5 畫
かくt #KJ*5 缺
かくt #KJ*5 舁
かくすt #KJ*11 隠
かくすt #KJ*5 祕
かくすt #KJ*5 隱
かくれるt #KJ*11 隠
かくれるt #KJ*5 竄
かくれるt #KJ*5 藏
かくれるt #KJ*5 蟄
かくれるt #KJ*5 隱
かぐt #KJ*5 嗅
かけるt #KJ*13 欠
かけるt #KJ*11 懸
かけるt #KJ*11 掛
かけるt #KJ*11 架
かけるt #KJ*11 駆
かけるt #KJ*7 繋
かけるt #KJ*7 賭
かけるt #KJ*7 駈
かけるt #KJ*5 挂
かけるt #KJ*5 縣
かけるt #KJ*5 缺
かけるt #KJ*5 翔
かけるt #KJ*5 虧
かけるt #KJ*5 闕
かけるt #KJ*5 驅
かげるt #KJ*11 陰
かげるt #KJ*5 翳
かこいt #KJ*5 圈
かこいt #KJ*5 埒
かこいt #KJ*5 埓
かこうt #KJ*13 囲
かこうt #KJ*5 圍
かこむt #KJ*13 囲
かこむt #KJ*5 圍
かさなるt #KJ*13 重
かさなるt #KJ*5 疂
かさなるt #KJ*5 疉
かさなるt #KJ*5 疊
かさなるt #KJ*5 縲
かさねるt #KJ*13 重
かさねるt #KJ*5 疂
かさねるt #KJ*5 疉
かさねるt #KJ*5 疊
かさねるt #KJ*5 縲
かさむt #KJ*7 嵩
かざすt #KJ*5 翳
かざりt #KJ*5 餝
かざるt #KJ*11 飾
かざるt #KJ*5 餝
かしぐt #KJ*5 爨
かしこいt #KJ*11 賢
かしこいt #KJ*5 俐
かしこしt #KJ*7 畏
かしこまるt #KJ*7 畏
かしずくt #KJ*5 傅
かしましいt #KJ*7 姦
かじるt #KJ*5 囓
かじるt #KJ*5 齧
かすt #KJ*13 貸
かすむt #KJ*7 霞
かすめるt #KJ*7 掠
かせぐt #KJ*9 稼
かぞえるt #KJ*13 数
かぞえるt #KJ*5 數
かたいt #KJ*13 固
かたいt #KJ*13 難
かたいt #KJ*11 堅
かたいt #KJ*11 硬
かたいt #KJ*5 艱
かたいt #KJ*5 鞏
かたじけないt #KJ*5 忝
かたどるt #KJ*7 貌
かたどるt #KJ*5 皃
かたぬぐt #KJ*5 袒
かたまるt #KJ*13 固
かたむくt #KJ*11 傾
かたむくt #KJ*5 仄
かたむくt #KJ*5 昃
かたむけるt #KJ*11 傾
かためるt #KJ*13 固
かたよるt #KJ*11 偏
かたよるt #KJ*7 頗
かたらうt #KJ*13 語
かたるt #KJ*13 語
かたるt #KJ*5 騙
かたわらt #KJ*11 傍
かたわらt #KJ*5 旁
かつt #KJ*13 勝
かつt #KJ*11 且
かつt #KJ*11 克
かつt #KJ*7 捷
かつt #KJ*5 剋
かつt #KJ*5 尅
かつぐt #KJ*13 担
かつぐt #KJ*5 擔
かつてt #KJ*7 嘗
かつてt #KJ*7 曽
かつてt #KJ*7 曾
かつてt #KJ*5 甞
かないt #KJ*7 叶
かなうt #KJ*7 叶
かなうt #KJ*5 恊
かなうt #KJ*5 稱
かなうt #KJ*5 諧
かなしいt #KJ*13 悲
かなしむt #KJ*13 悲
かなでるt #KJ*13 奏
かならずt #KJ*13 必
かねてt #KJ*5 豫
かねるt #KJ*11 兼
かねるt #KJ*5 攝
かのt #KJ*11 彼
かばうt #KJ*7 庇
かびるt #KJ*5 黴
かまうt #KJ*13 構
かまえるt #KJ*13 構
かまびすしいt #KJ*7 喧
かまびすしいt #KJ*7 嘩
かまびすしいt #KJ*5 呶
かまびすしいt #KJ*5 囂
かまびすしいt #KJ*5 聒
かまびすしいt #KJ*5 諠
かまびすしいt #KJ*5 譁
かまびすしいt #KJ*5 讙
かむt #KJ*7 噛
かむt #KJ*5 咀
かむt #KJ*5 咬
かむt #KJ*5 嚼
かむt #KJ*5 囓
かむt #KJ*5 齟
かむt #KJ*5 齧
かもすt #KJ*11 醸
かもすt #KJ*7 醗
かもすt #KJ*5 釀
かゆいt #KJ*5 痒
かゆいt #KJ*5 癢
かようt #KJ*13 通
かよわいt #KJ*5 孅
からいt #KJ*11 辛
からいt #KJ*7 苛
からいt #KJ*5 辣
からかうt #KJ*5 揶
からげるt #KJ*5 縢
からすt #KJ*11 枯
からまるt #KJ*11 絡
からむt #KJ*11 絡
からめるt #KJ*5 搦
かりt #KJ*13 借
かりt #KJ*11 狩
かりt #KJ*5 獵
かりるt #KJ*13 借
かりるt #KJ*5 藉
かるt #KJ*11 刈
かるt #KJ*11 狩
かるt #KJ*11 駆
かるt #KJ*7 苅
かるt #KJ*7 駈
かるt #KJ*5 乂
かるt #KJ*5 獵
かるt #KJ*5 艾
かるt #KJ*5 芟
かるt #KJ*5 驅
かるいt #KJ*13 軽
かるいt #KJ*5 嫖
かるいt #KJ*5 輕
かれるt #KJ*11 枯
かれるt #KJ*5 嗄
かれるt #KJ*5 槁
かれるt #KJ*5 沍
かれるt #KJ*5 涸
かろやかt #KJ*13 軽
かろやかt #KJ*5 輕
かろんじるt #KJ*5 藐
かわかすt #KJ*11 乾
かわくt #KJ*11 乾
かわくt #KJ*11 渇
かわくt #KJ*5 晞
かわすt #KJ*13 交
かわすt #KJ*5 躱
かわるt #KJ*13 代
かわるt #KJ*13 変
かわるt #KJ*11 換
かわるt #KJ*11 替
かわるt #KJ*5 渝
かわるt #KJ*5 變
かわるt #KJ*5 遞
かんがえるt #KJ*13 考
かんがえるt #KJ*7 稽
かんがえるt #KJ*5 攷
かんがみるt #KJ*5 鑒
かんばしいt #KJ*11 芳
がりt #KJ*11 狩
きえるt #KJ*13 消
きえるt #KJ*5 熄
きくt #KJ*13 利
きくt #KJ*13 効
きくt #KJ*13 聞
きくt #KJ*11 聴
きくt #KJ*5 效
きくt #KJ*5 聽
きこえるt #KJ*13 聞
きこるt #KJ*7 樵
きざしt #KJ*13 兆
きざすt #KJ*13 兆
きざすt #KJ*7 萌
きざすt #KJ*5 萠
きざむt #KJ*13 刻
きざむt #KJ*5 剞
きざむt #KJ*5 雕
きしるt #KJ*5 軋
きしるt #KJ*5 輾
きしるt #KJ*5 轢
きしるt #KJ*5 轣
きずくt #KJ*13 築
きせるt #KJ*13 着
きそうt #KJ*13 競
きそうt #KJ*5 竸
きたえるt #KJ*11 鍛
きたすt #KJ*13 来
きたすt #KJ*5 來
きたすt #KJ*5 徠
きたないt #KJ*11 汚
きたるt #KJ*13 来
きたるt #KJ*5 來
きたるt #KJ*5 徠
きびしいt #KJ*13 厳
きびしいt #KJ*5 嚴
きびしいt #KJ*5 峭
きまるt #KJ*13 決
きまるt #KJ*5 决
きめるt #KJ*13 決
きめるt #KJ*5 决
きよいt #KJ*13 清
きよいt #KJ*5 洌
きよいt #KJ*5 淨
きよいt #KJ*5 澂
きよいt #KJ*5 瀏
きよいt #KJ*5 皎
きよまるt #KJ*13 清
きよめるt #KJ*13 清
きらうt #KJ*9 嫌
きるt #KJ*13 切
きるt #KJ*13 着
きるt #KJ*7 斬
きるt #KJ*5 剪
きるt #KJ*5 截
きるt #KJ*5 斫
きるt #KJ*5 鑚
きるt #KJ*5 鑽
きれるt #KJ*13 切
きわまるt #KJ*13 極
きわまるt #KJ*11 窮
きわみt #KJ*13 極
きわめるt #KJ*13 極
きわめるt #KJ*13 究
きわめるt #KJ*11 窮
くいt #KJ*7 咋
くいt #KJ*7 喰
くいるt #KJ*11 悔
くいるt #KJ*5 懴
くいるt #KJ*5 懺
くうt #KJ*13 食
くうt #KJ*7 咋
くうt #KJ*7 喰
くうt #KJ*5 啖
くうt #KJ*5 餔
くぐるt #KJ*5 潛
くぐるt #KJ*5 濳
くけるt #KJ*5 絎
くさいt #KJ*11 臭
くさぎるt #KJ*5 耨
くさらすt #KJ*11 腐
くさるt #KJ*11 腐
くされるt #KJ*11 腐
くしけずるt #KJ*5 梳
くじくt #KJ*7 挫
くじけるt #KJ*7 挫
くすぐるt #KJ*5 擽
くすぶるt #KJ*5 燻
くすべるt #KJ*5 熏
くすべるt #KJ*5 燻
くずすt #KJ*11 崩
くずれるt #KJ*11 崩
くずれるt #KJ*5 頽
くだくt #KJ*11 砕
くだくt #KJ*5 拉
くだくt #KJ*5 摧
くだくt #KJ*5 碎
くだけるt #KJ*11 砕
くだけるt #KJ*5 碎
くださるt #KJ*13 下
くだすt #KJ*13 下
くだるt #KJ*13 下
くちすすぐt #KJ*5 嗽
くちるt #KJ*11 朽
くつがえすt #KJ*11 覆
くつがえるt #KJ*11 覆
くばるt #KJ*13 配
くびきるt #KJ*5 剄
くびきるt #KJ*5 馘
くびはねるt #KJ*5 刎
くびるt #KJ*5 縊
くびれるt #KJ*5 經
くびれるt #KJ*5 縊
くぼみt #KJ*9 凹
くぼむt #KJ*9 凹
くぼむt #KJ*7 窪
くみt #KJ*7 汲
くみするt #KJ*5 與
くむt #KJ*13 組
くむt #KJ*9 酌
くむt #KJ*7 汲
くむt #KJ*5 抒
くむt #KJ*5 斟
くもるt #KJ*11 曇
くやしいt #KJ*11 悔
くやむt #KJ*11 悔
くらいt #KJ*13 暗
くらいt #KJ*7 冥
くらいt #KJ*7 昏
くらいt #KJ*7 昧
くらいt #KJ*7 晦
くらいt #KJ*7 闇
くらいt #KJ*5 暝
くらいt #KJ*5 曖
くらいt #KJ*5 曚
くらいt #KJ*5 杳
くらいt #KJ*5 梦
くらいt #KJ*5 溟
くらいt #KJ*5 眛
くらいt #KJ*5 瞑
くらいt #KJ*5 矇
くらいt #KJ*5 罔
くらいt #KJ*5 黯
くらうt #KJ*13 食
くらうt #KJ*7 喰
くらうt #KJ*5 啖
くらうt #KJ*5 啗
くらすt #KJ*13 暮
くらべるt #KJ*13 比
くらむt #KJ*5 眩
くりt #KJ*11 繰
くるt #KJ*13 来
くるt #KJ*11 繰
くるt #KJ*5 來
くるt #KJ*5 徠
くるうt #KJ*11 狂
くるうt #KJ*5 猖
くるおしいt #KJ*11 狂
くるしいt #KJ*13 苦
くるしむt #KJ*13 苦
くるしむt #KJ*5 窘
くるしめるt #KJ*13 苦
くれるt #KJ*13 暮
くろいt #KJ*13 黒
くろいt #KJ*5 黎
くろいt #KJ*5 黔
くわえるt #KJ*13 加
くわしいt #KJ*11 詳
くわしいt #KJ*5 粹
くわだてるt #KJ*11 企
くわわるt #KJ*13 加
けがすt #KJ*11 汚
けがすt #KJ*7 涜
けがすt #KJ*5 黷
けがらわしいt #KJ*11 汚
けがれt #KJ*5 穢
けがれるt #KJ*11 汚
けがれるt #KJ*5 溷
けがれるt #KJ*5 穢
けがれるt #KJ*5 褻
けがれるt #KJ*5 黷
けすt #KJ*13 消
けすt #KJ*5 銷
けずるt #KJ*11 削
けずるt #KJ*5 刪
けずるt #KJ*5 刮
けだしt #KJ*7 蓋
けだしt #KJ*5 盖
けだしt #KJ*5 葢
けむいt #KJ*11 煙
けむいt #KJ*5 烟
けむるt #KJ*11 煙
けむるt #KJ*5 烟
けるt #KJ*7 蹴
けわしいt #KJ*13 険
けわしいt #KJ*7 峻
けわしいt #KJ*7 巌
けわしいt #KJ*5 峭
けわしいt #KJ*5 嵜
けわしいt #KJ*5 嶇
けわしいt #KJ*5 嶮
けわしいt #KJ*5 巖
けわしいt #KJ*5 隗
けわしいt #KJ*5 險
こいt #KJ*11 濃
こいt #KJ*7 乞
こいしいt #KJ*11 恋
こいしいt #KJ*5 戀
こいねがうt #KJ*5 冀
こいねがわくはt #KJ*5 冀
こうt #KJ*11 恋
こうt #KJ*11 請
こうt #KJ*7 乞
こうt #KJ*5 丐
こうt #KJ*5 戀
こうばしいt #KJ*5 芬
こうむるt #KJ*11 被
こえるt #KJ*13 肥
こえるt #KJ*11 超
こえるt #KJ*11 越
こえるt #KJ*5 腴
こえるt #KJ*5 踰
こえるt #KJ*5 逾
こおるt #KJ*11 凍
こおるt #KJ*5 凅
こおるt #KJ*5 沍
こがすt #KJ*11 焦
こがれるt #KJ*11 焦
こくt #KJ*11 扱
こぐt #KJ*7 漕
こげるt #KJ*11 焦
ここにt #KJ*5 于
ここにt #KJ*5 曰
ここにt #KJ*5 焉
ここにt #KJ*5 爰
ここにt #KJ*5 粤
ここにt #KJ*5 聿
ここにt #KJ*5 茲
ここのつt #KJ*13 九
こころざすt #KJ*13 志
こころみるt #KJ*13 試
こころみるt #KJ*7 嘗
こころみるt #KJ*5 甞
こころよいt #KJ*13 快
こごえるt #KJ*11 凍
こしt #KJ*7 漉
こしらえるt #KJ*5 拵
こすt #KJ*11 超
こすt #KJ*11 越
こすt #KJ*7 漉
こすt #KJ*5 濾
こすt #KJ*5 踰
こぞってt #KJ*5 擧
こぞってt #KJ*5 舉
こたえるt #KJ*13 答
こたえるt #KJ*5 對
こたえるt #KJ*5 應
ことごとくt #KJ*7 悉
ことごとくt #KJ*7 畢
ことごとくt #KJ*5 儘
ことごとくt #KJ*5 盡
ことほぐt #KJ*5 壽
ことわるt #KJ*13 断
ことわるt #KJ*5 斷
ことわるt #KJ*5 辭
こねるt #KJ*5 捏
このt #KJ*7 斯
このむt #KJ*13 好
こばむt #KJ*11 拒
こびるt #KJ*5 媚
こぼつt #KJ*5 毀
こまかt #KJ*13 細
こまかいt #KJ*13 細
こまかいt #KJ*5 緻
こまぬくt #KJ*5 拱
こまねくt #KJ*5 拱
こまるt #KJ*13 困
こむt #KJ*11 込
こめるt #KJ*11 込
こめるt #KJ*5 罩
こもるt #KJ*7 篭
こもるt #KJ*5 籠
こやしt #KJ*13 肥
こやすt #KJ*13 肥
こらえるt #KJ*5 怺
こらしめるt #KJ*11 懲
こらすt #KJ*11 凝
こらすt #KJ*11 懲
こりるt #KJ*11 懲
こるt #KJ*11 凝
これt #KJ*5 焉
ころがすt #KJ*13 転
ころがすt #KJ*5 轉
ころがるt #KJ*13 転
ころがるt #KJ*5 轉
ころげるt #KJ*13 転
ころげるt #KJ*5 轉
ころすt #KJ*13 殺
ころすt #KJ*5 戮
ころすt #KJ*5 誅
ころぶt #KJ*13 転
ころぶt #KJ*5 轉
こわいt #KJ*11 怖
こわすt #KJ*11 壊
こわすt #KJ*5 壞
こわれるt #KJ*11 壊
こわれるt #KJ*5 壞
ござるt #KJ*5 厶
ごとしt #KJ*11 如
さいわいt #KJ*13 幸
さいわいt #KJ*7 倖
さえぎるt #KJ*9 遮
さえずるt #KJ*5 哢
さえずるt #KJ*5 囀
さえるt #KJ*7 冴
さかえt #KJ*5 榮
さかえるt #KJ*13 栄
さかえるt #KJ*5 榮
さかさt #KJ*13 逆
さかのぼるt #KJ*7 遡
さかのぼるt #KJ*5 泝
さかのぼるt #KJ*5 溯
さからうt #KJ*13 逆
さからうt #KJ*5 忤
さかるt #KJ*13 盛
さかんt #KJ*13 盛
さかんt #KJ*7 旺
さかんt #KJ*7 昌
さかんt #KJ*5 壯
さかんt #KJ*5 奘
さかんt #KJ*5 弉
さかんt #KJ*5 殷
さかんt #KJ*5 熾
さがすt #KJ*13 探
さがすt #KJ*11 捜
さがすt #KJ*5 搜
さがるt #KJ*13 下
さきt #KJ*11 咲
さきにt #KJ*5 嚮
さきにt #KJ*5 曩
さくt #KJ*13 割
さくt #KJ*11 咲
さくt #KJ*11 裂
さくt #KJ*5 决
さくt #KJ*5 劈
さくt #KJ*5 拆
さくt #KJ*5 擘
さくt #KJ*5 槭
さくt #KJ*5 磔
さぐるt #KJ*13 探
さけぶt #KJ*11 叫
さけぶt #KJ*5 喊
さけぶt #KJ*5 嘖
さけぶt #KJ*5 號
さけるt #KJ*11 裂
さけるt #KJ*11 避
さげすむt #KJ*7 蔑
さげるt #KJ*13 下
さげるt #KJ*13 提
ささえるt #KJ*13 支
ささげるt #KJ*7 捧
ささやくt #KJ*5 囁
ささやくt #KJ*5 聶
ささるt #KJ*11 刺
さしはさむt #KJ*5 縉
さしまねくt #KJ*5 麾
さすt #KJ*13 差
さすt #KJ*13 指
さすt #KJ*11 刺
さすt #KJ*9 挿
さすt #KJ*5 扠
さすt #KJ*5 插
さすt #KJ*5 螫
さすがにt #KJ*5 遉
さずかるt #KJ*13 授
さずけるt #KJ*13 授
さそうt #KJ*11 誘
さそうt #KJ*5 哘
さだかt #KJ*13 定
さだまるt #KJ*13 定
さだめるt #KJ*13 定
さだめるt #KJ*5 奠
さだめるt #KJ*5 斷
さといt #KJ*7 聡
さといt #KJ*5 聰
さといt #KJ*5 黠
さとすt #KJ*11 諭
さとすt #KJ*5 喩
さとるt #KJ*11 悟
さとるt #KJ*5 惺
さとるt #KJ*5 曉
さとるt #KJ*5 覺
さとるt #KJ*5 觧
さばきt #KJ*7 捌
さばくt #KJ*13 裁
さばくt #KJ*7 捌
さばけるt #KJ*7 捌
さびしいt #KJ*11 寂
さびしいt #KJ*7 淋
さびしいt #KJ*5 寞
さびしいt #KJ*5 寥
さびれるt #KJ*11 寂
さますt #KJ*13 冷
さますt #KJ*13 覚
さますt #KJ*7 醒
さますt #KJ*5 覺
さまたげるt #KJ*11 妨
さまようt #KJ*5 彷
さまようt #KJ*5 徘
さまようt #KJ*5 徨
さむいt #KJ*13 寒
さむいt #KJ*7 凄
さむいt #KJ*5 冱
さむいt #KJ*5 淒
さめるt #KJ*13 冷
さめるt #KJ*13 覚
さめるt #KJ*7 醒
さめるt #KJ*5 寤
さめるt #KJ*5 覺
さらうt #KJ*5 浚
さらうt #KJ*5 渫
さらしt #KJ*7 晒
さらすt #KJ*7 晒
さらすt #KJ*7 曝
さるt #KJ*13 去
さわがしいt #KJ*5 閙
さわがしいt #KJ*5 鬧
さわぐt #KJ*11 騒
さわぐt #KJ*5 噪
さわぐt #KJ*5 譟
さわぐt #KJ*5 躁
さわぐt #KJ*5 騷
さわやかt #KJ*7 爽
さわるt #KJ*13 障
さわるt #KJ*11 触
さわるt #KJ*5 觸
ざれt #KJ*5 戲
しあわせt #KJ*13 幸
しいたげるt #KJ*11 虐
しいるt #KJ*13 強
しいるt #KJ*5 罔
しいるt #KJ*5 誣
しおからいt #KJ*5 鹹
しかしてt #KJ*7 而
しかとt #KJ*5 聢
しかめるt #KJ*5 顰
しかもt #KJ*7 而
しかりt #KJ*7 爾
しかりt #KJ*5 尓
しかるt #KJ*7 叱
しかるt #KJ*5 呵
しかるt #KJ*5 咄
しかるt #KJ*5 咤
しかるt #KJ*5 訶
しかれどもt #KJ*7 而
しきt #KJ*7 鋪
しきりにt #KJ*5 仍
しきりにt #KJ*5 縲
しきりにt #KJ*5 荐
しくt #KJ*11 敷
しくt #KJ*7 鋪
しくt #KJ*5 舖
しげしt #KJ*5 縟
しげるt #KJ*11 滋
しげるt #KJ*11 繁
しげるt #KJ*11 茂
しげるt #KJ*7 蕃
しげるt #KJ*5 孳
しげるt #KJ*5 稠
しげるt #KJ*5 茲
しげるt #KJ*5 鬱
しずかt #KJ*13 静
しずかt #KJ*5 謐
しずかt #KJ*5 闃
しずかt #KJ*5 靜
しずまるt #KJ*13 静
しずまるt #KJ*11 鎮
しずまるt #KJ*5 鎭
しずまるt #KJ*5 靜
しずむt #KJ*11 沈
しずむt #KJ*7 湛
しずむt #KJ*5 汨
しずむt #KJ*5 沒
しずむt #KJ*5 淪
しずむt #KJ*5 湎
しずむt #KJ*5 湮
しずめるt #KJ*13 静
しずめるt #KJ*11 沈
しずめるt #KJ*11 鎮
しずめるt #KJ*5 鎭
しずめるt #KJ*5 靜
したうt #KJ*11 慕
したがうt #KJ*13 従
したがうt #KJ*7 遜
したがうt #KJ*5 从
したがうt #KJ*5 婉
したがうt #KJ*5 徇
したがうt #KJ*5 從
したがうt #KJ*5 扈
したがうt #KJ*5 隨
したがうt #KJ*5 隸
したがえるt #KJ*13 従
したがえるt #KJ*5 從
したしいt #KJ*13 親
したしむt #KJ*13 親
したたるt #KJ*11 滴
したたるt #KJ*5 瀝
しぬt #KJ*13 死
しぬt #KJ*5 歿
しぬt #KJ*5 殞
しぬt #KJ*5 沒
しのぐt #KJ*7 凌
しのぐt #KJ*7 駕
しのばせるt #KJ*11 忍
しのびt #KJ*7 偲
しのぶt #KJ*11 忍
しのぶt #KJ*7 偲
しばらくt #KJ*7 姑
しばらくt #KJ*7 頃
しばるt #KJ*11 縛
しびれるt #KJ*5 痲
しぶいt #KJ*11 渋
しぶいt #KJ*5 澀
しぶいt #KJ*5 澁
しぶるt #KJ*11 渋
しぶるt #KJ*5 澀
しぶるt #KJ*5 澁
しぼむt #KJ*7 凋
しぼりt #KJ*5 纈
しぼるt #KJ*11 搾
しぼるt #KJ*11 絞
しまるt #KJ*13 閉
しまるt #KJ*11 絞
しまるt #KJ*11 締
しまるt #KJ*5 閇
しみt #KJ*13 染
しみるt #KJ*13 染
しみるt #KJ*5 沁
しみるt #KJ*5 滲
しむt #KJ*5 俾
しめすt #KJ*13 示
しめすt #KJ*11 湿
しめすt #KJ*5 濕
しめすt #KJ*5 觀
しめるt #KJ*13 閉
しめるt #KJ*11 占
しめるt #KJ*11 湿
しめるt #KJ*11 絞
しめるt #KJ*11 締
しめるt #KJ*5 濕
しめるt #KJ*5 閇
しゃべるt #KJ*7 喋
しらせt #KJ*5 訃
しらべるt #KJ*13 調
しらべるt #KJ*5 檢
しらべるt #KJ*5 覈
しりぞくt #KJ*13 退
しりぞくt #KJ*5 卻
しりぞくt #KJ*5 屏
しりぞくt #KJ*5 逡
しりぞけるt #KJ*13 退
しりぞけるt #KJ*5 卻
しりぞけるt #KJ*5 屏
しりぞけるt #KJ*5 擯
しりぞけるt #KJ*5 黜
しるt #KJ*13 知
しるすt #KJ*13 記
しろいt #KJ*13 白
しろいt #KJ*5 皎
しろいt #KJ*5 皓
しろいt #KJ*5 皙
しろいt #KJ*5 皚
すいt #KJ*13 酸
すうt #KJ*13 吸
すうt #KJ*5 吮
すうt #KJ*5 呷
すうt #KJ*5 歙
すえt #KJ*9 据
すえるt #KJ*9 据
すえるt #KJ*5 饐
すかすt #KJ*11 透
すかすt #KJ*5 賺
すがるt #KJ*5 縋
すきt #KJ*7 漉
すぎるt #KJ*13 過
すぎるt #KJ*7 宕
すぎるt #KJ*5 軼
すくt #KJ*13 好
すくt #KJ*11 透
すくt #KJ*7 漉
すくt #KJ*5 梳
すくうt #KJ*13 救
すくうt #KJ*7 掬
すくうt #KJ*5 抔
すくうt #KJ*5 拯
すくうt #KJ*5 濟
すくないt #KJ*13 少
すくないt #KJ*5 尠
すくむt #KJ*5 竦
すぐれるt #KJ*13 優
すぐれるt #KJ*5 儁
すぐれるt #KJ*5 儻
すけるt #KJ*11 透
すこしt #KJ*13 少
すこしt #KJ*5 毫
すこぶるt #KJ*7 頗
すこやかt #KJ*13 健
すごいt #KJ*7 凄
すごいt #KJ*5 淒
すごすt #KJ*13 過
すさまじいt #KJ*7 凄
すさまじいt #KJ*5 淒
すすぐt #KJ*5 漱
すすむt #KJ*13 進
すすむt #KJ*7 晋
すすむt #KJ*5 晉
すすめるt #KJ*13 進
すすめるt #KJ*11 勧
すすめるt #KJ*11 薦
すすめるt #KJ*5 侑
すすめるt #KJ*5 勸
すすめるt #KJ*5 奬
すすめるt #KJ*5 獎
すすめるt #KJ*5 羞
すすりなくt #KJ*5 歔
すするt #KJ*5 啜
すするt #KJ*5 歃
すずしいt #KJ*11 涼
すずしいt #KJ*5 凉
すずむt #KJ*11 涼
すずむt #KJ*5 凉
すたるt #KJ*11 廃
すたるt #KJ*5 廢
すたれるt #KJ*11 廃
すたれるt #KJ*5 廢
すてるt #KJ*13 捨
すてるt #KJ*5 弃
すてるt #KJ*5 捐
すてるt #KJ*5 釋
すでにt #KJ*11 既
すでにt #KJ*5 已
すなわちt #KJ*11 即
すなわちt #KJ*7 乃
すなわちt #KJ*7 廼
すなわちt #KJ*7 曽
すなわちt #KJ*7 曾
すなわちt #KJ*7 而
すなわちt #KJ*5 輒
すなわちt #KJ*5 輙
すなわちt #KJ*5 迺
すねるt #KJ*5 拗
すべからくt #KJ*7 須
すべてt #KJ*13 総
すべてt #KJ*5 渾
すべるt #KJ*13 統
すべるt #KJ*11 滑
すべるt #KJ*5 總
すべるt #KJ*5 辷
すまうt #KJ*13 住
すますt #KJ*13 済
すますt #KJ*11 澄
すますt #KJ*5 澂
すますt #KJ*5 濟
すみやかt #KJ*13 速
すみやかt #KJ*5 亟
すみやかt #KJ*5 遽
すむt #KJ*13 住
すむt #KJ*13 済
すむt #KJ*11 澄
すむt #KJ*7 栖
すむt #KJ*7 棲
すむt #KJ*5 澂
すむt #KJ*5 濟
すりt #KJ*7 摺
するt #KJ*13 刷
するt #KJ*11 擦
するt #KJ*5 掏
するt #KJ*5 搨
するt #KJ*5 擂
するどいt #KJ*11 鋭
すれるt #KJ*11 擦
すわるt #KJ*13 座
すわるt #KJ*9 据
すわるt #KJ*7 坐
ずるいt #KJ*5 狡
せくt #KJ*7 堰
せぐくまるt #KJ*5 跼
せばまるt #KJ*11 狭
せばまるt #KJ*5 狹
せばめるt #KJ*11 狭
せばめるt #KJ*5 狹
せまいt #KJ*11 狭
せまいt #KJ*7 窄
せまいt #KJ*5 狹
せまいt #KJ*5 褊
せまいt #KJ*5 阨
せまいt #KJ*5 陋
せまいt #KJ*5 隘
せまるt #KJ*11 迫
せまるt #KJ*7 拶
せまるt #KJ*7 逼
せまるt #KJ*5 蹙
せまるt #KJ*5 逎
せまるt #KJ*5 遒
せめぐt #KJ*5 鬩
せめるt #KJ*13 責
せめるt #KJ*11 攻
せめるt #KJ*5 誅
せめるt #KJ*5 誚
せめるt #KJ*5 謫
せめるt #KJ*5 譴
せるt #KJ*13 競
せるt #KJ*5 竸
そうt #KJ*13 沿
そうt #KJ*11 添
そうろうt #KJ*13 候
そえるt #KJ*11 添
そこなうt #KJ*13 損
そこなうt #KJ*5 殘
そこねるt #KJ*13 損
そしるt #KJ*7 誹
そしるt #KJ*5 毀
そしるt #KJ*5 詆
そしるt #KJ*5 謗
そしるt #KJ*5 譏
そしるt #KJ*5 譖
そしるt #KJ*5 譛
そしるt #KJ*5 讒
そそぐt #KJ*13 注
そそぐt #KJ*7 沃
そそぐt #KJ*7 潅
そそぐt #KJ*5 漑
そそぐt #KJ*5 澆
そそぐt #KJ*5 濺
そそぐt #KJ*5 灌
そそぐt #KJ*5 灑
そそのかすt #KJ*11 唆
そそのかすt #KJ*5 嗾
そぞろにt #KJ*7 坐
そだつt #KJ*13 育
そだつt #KJ*5 毓
そだてるt #KJ*13 育
そだてるt #KJ*5 毓
そなえt #KJ*5 饌
そなえるt #KJ*13 供
そなえるt #KJ*13 備
そなえるt #KJ*5 饌
そなわるt #KJ*13 備
そのt #KJ*7 其
そのt #KJ*5 厥
そのt #KJ*5 尓
そばだつt #KJ*5 屹
そばだつt #KJ*5 峙
そばだつt #KJ*5 崛
そばだつt #KJ*5 欹
そびえるt #KJ*5 聳
そまるt #KJ*13 染
そむくt #KJ*13 背
そむくt #KJ*7 叛
そむくt #KJ*5 乖
そむくt #KJ*5 韋
そむけるt #KJ*13 背
そめるt #KJ*13 初
そめるt #KJ*13 染
そめるt #KJ*5 涅
そらすt #KJ*13 反
そらすt #KJ*11 逸
そらんじるt #KJ*5 諳
そるt #KJ*13 反
そるt #KJ*7 剃
それるt #KJ*11 逸
そろいt #KJ*7 揃
そろうt #KJ*7 揃
そろえるt #KJ*7 揃
たいらt #KJ*13 平
たいらt #KJ*7 坦
たいらげるt #KJ*7 夷
たえるt #KJ*13 絶
たえるt #KJ*11 堪
たえるt #KJ*11 耐
たおすt #KJ*11 倒
たおすt #KJ*5 仆
たおすt #KJ*5 殪
たおやかt #KJ*5 婀
たおやかt #KJ*5 嫋
たおれるt #KJ*11 倒
たおれるt #KJ*5 仆
たおれるt #KJ*5 僵
たおれるt #KJ*5 斃
たかいt #KJ*13 高
たかいt #KJ*11 隆
たかいt #KJ*7 喬
たかいt #KJ*7 尭
たかいt #KJ*7 峻
たかいt #KJ*7 嵩
たかいt #KJ*5 堯
たかいt #KJ*5 岌
たかいt #KJ*5 崛
たかいt #KJ*5 巍
たかいt #KJ*5 敞
たかいt #KJ*5 杲
たかいt #KJ*5 魏
たかぶるt #KJ*5 亢
たかまるt #KJ*13 高
たかめるt #KJ*13 高
たがいt #KJ*11 互
たがいにt #KJ*5 遞
たがうt #KJ*7 爽
たがやすt #KJ*13 耕
たがやすt #KJ*5 畊
たぎるt #KJ*5 滾
たくt #KJ*11 炊
たくt #KJ*7 焚
たくましいt #KJ*5 逞
たくわえるt #KJ*11 蓄
たけしt #KJ*13 健
たけしt #KJ*13 武
たけしt #KJ*11 猛
たけしt #KJ*7 毅
たけしt #KJ*5 悍
たけるt #KJ*11 猛
たしかt #KJ*13 確
たしかめるt #KJ*13 確
たしなみt #KJ*5 嗜
たしなむt #KJ*5 嗜
たしなめるt #KJ*5 窘
たすt #KJ*13 足
たすかるt #KJ*13 助
たすけt #KJ*7 祐
たすけt #KJ*7 輔
たすけるt #KJ*13 助
たすけるt #KJ*7 丞
たすけるt #KJ*7 佑
たすけるt #KJ*7 弼
たすけるt #KJ*7 祐
たすけるt #KJ*7 輔
たすけるt #KJ*5 侑
たすけるt #KJ*5 奬
たすけるt #KJ*5 幇
たすけるt #KJ*5 掖
たすけるt #KJ*5 獎
たすけるt #KJ*5 裨
たすけるt #KJ*5 贊
たずさえるt #KJ*11 携
たずさえるt #KJ*5 攜
たずさわるt #KJ*11 携
たずさわるt #KJ*5 攜
たずねるt #KJ*13 訪
たずねるt #KJ*11 尋
たずねるt #KJ*5 繹
たたえるt #KJ*7 湛
たたえるt #KJ*5 稱
たたえるt #KJ*5 贊
たたえるt #KJ*5 頌
たたかいt #KJ*5 戰
たたかうt #KJ*13 戦
たたかうt #KJ*11 闘
たたかうt #KJ*5 戰
たたかうt #KJ*5 鬪
たたきt #KJ*7 叩
たたくt #KJ*7 叩
たたくt #KJ*5 扣
たたくt #KJ*5 敲
たたくt #KJ*5 毆
たたずむt #KJ*5 佇
たたずむt #KJ*5 竚
たたみt #KJ*5 疂
たたむt #KJ*11 畳
たたむt #KJ*5 疂
たたむt #KJ*5 疉
たたむt #KJ*5 疊
たたりt #KJ*5 祟
ただしt #KJ*11 但
ただしいt #KJ*13 正
ただすt #KJ*13 正
ただすt #KJ*7 匡
ただすt #KJ*7 董
ただすt #KJ*5 尹
ただすt #KJ*5 彈
ただすt #KJ*5 糺
ただすt #KJ*5 繩
ただすt #KJ*5 貭
ただすt #KJ*5 飭
ただちにt #KJ*13 直
ただちにt #KJ*5 徑
ただちにt #KJ*5 逕
ただようt #KJ*11 漂
ただようt #KJ*5 漾
ただれるt #KJ*5 爛
ただれるt #KJ*5 糜
たちまちt #KJ*7 乍
たちまちt #KJ*7 忽
たちまちt #KJ*5 倏
たっといt #KJ*13 尊
たっといt #KJ*13 貴
たっとぶt #KJ*13 尊
たっとぶt #KJ*13 貴
たつt #KJ*13 建
たつt #KJ*13 断
たつt #KJ*13 立
たつt #KJ*13 絶
たつt #KJ*13 裁
たつt #KJ*5 截
たつt #KJ*5 斷
たつt #KJ*5 殄
たつt #KJ*5 謖
たてまつるt #KJ*11 奉
たてまつるt #KJ*5 獻
たてるt #KJ*13 建
たてるt #KJ*13 立
たとえt #KJ*5 縱
たとえt #KJ*5 譬
たとえるt #KJ*13 例
たとえるt #KJ*5 喩
たとえるt #KJ*5 譬
たどりt #KJ*7 辿
たどるt #KJ*7 辿
たのしいt #KJ*13 楽
たのしいt #KJ*5 樂
たのしむt #KJ*13 楽
たのしむt #KJ*7 嬉
たのしむt #KJ*5 佚
たのしむt #KJ*5 樂
たのしむt #KJ*5 煕
たのしむt #KJ*5 熈
たのしむt #KJ*5 熙
たのむt #KJ*11 頼
たのむt #KJ*5 倚
たのむt #KJ*5 怙
たのむt #KJ*5 恃
たのむt #KJ*5 憑
たのむt #KJ*5 馮
たのもしいt #KJ*11 頼
たぶらかすt #KJ*5 誑
たべるt #KJ*13 食
たまうt #KJ*5 賚
たまりt #KJ*7 溜
たまわるt #KJ*11 賜
たむろするt #KJ*9 屯
ためすt #KJ*13 試
ためすt #KJ*5 驗
ためにt #KJ*5 與
ためらうt #KJ*5 躇
ためらうt #KJ*5 躊
ためるt #KJ*9 矯
たもつt #KJ*13 保
たやすt #KJ*13 絶
たよりt #KJ*13 便
たよるt #KJ*11 頼
たらすt #KJ*13 垂
たらすt #KJ*5 埀
たらすt #KJ*5 誑
たりるt #KJ*13 足
たるt #KJ*13 足
たれるt #KJ*13 垂
たれるt #KJ*5 埀
たわむt #KJ*5 橈
たわむれt #KJ*5 詼
たわむれるt #KJ*11 戯
たわむれるt #KJ*5 戲
たわむれるt #KJ*5 謔
たわめるt #KJ*5 撓
たわめるt #KJ*5 橈
だくt #KJ*11 抱
だすt #KJ*13 出
だますt #KJ*5 瞞
だまるt #KJ*11 黙
だまるt #KJ*5 默
ちいさいt #KJ*13 小
ちいさいt #KJ*5 幺
ちいさいt #KJ*5 瑣
ちいさいt #KJ*5 纎
ちいさいt #KJ*5 纖
ちかいt #KJ*13 近
ちかいt #KJ*7 迩
ちかいt #KJ*5 邇
ちかうt #KJ*11 誓
ちかづくt #KJ*13 近
ちかづくt #KJ*5 昵
ちがうt #KJ*11 違
ちがえるt #KJ*11 違
ちぎるt #KJ*11 契
ちぢまるt #KJ*13 縮
ちぢむt #KJ*13 縮
ちぢめるt #KJ*13 縮
ちぢらすt #KJ*13 縮
ちぢれるt #KJ*13 縮
ちらかすt #KJ*13 散
ちらかるt #KJ*13 散
ちらすt #KJ*13 散
ちりばめるt #KJ*5 鏤
ちるt #KJ*13 散
ついえるt #KJ*13 費
ついえるt #KJ*7 潰
ついでt #KJ*5 繼
ついにt #KJ*5 卆
ついにt #KJ*5 竟
ついにt #KJ*5 訖
ついやすt #KJ*13 費
つかうt #KJ*13 使
つかうt #KJ*11 遣
つかえるt #KJ*13 仕
つかえるt #KJ*5 閊
つかさどるt #KJ*13 司
つかすt #KJ*11 尽
つかすt #KJ*5 盡
つかねるt #KJ*13 束
つかまえるt #KJ*11 捕
つかまるt #KJ*11 捕
つかみt #KJ*7 掴
つかむt #KJ*7 掴
つかむt #KJ*5 攫
つからすt #KJ*11 疲
つかるt #KJ*9 漬
つかれるt #KJ*11 疲
つかれるt #KJ*5 劬
つかれるt #KJ*5 勞
つかれるt #KJ*5 憊
つかれるt #KJ*5 瘁
つかれるt #KJ*5 羸
つかわすt #KJ*11 遣
つきるt #KJ*11 尽
つきるt #KJ*5 殄
つきるt #KJ*5 殫
つきるt #KJ*5 盡
つくt #KJ*13 付
つくt #KJ*13 就
つくt #KJ*13 着
つくt #KJ*11 即
つくt #KJ*11 突
つくt #KJ*11 衝
つくt #KJ*7 撞
つくt #KJ*7 貼
つくt #KJ*5 傅
つくt #KJ*5 屬
つくt #KJ*5 憑
つくt #KJ*5 搗
つくt #KJ*5 搶
つくt #KJ*5 擣
つくt #KJ*5 舂
つくすt #KJ*11 尽
つくすt #KJ*7 悉
つくすt #KJ*5 殄
つくすt #KJ*5 殱
つくすt #KJ*5 殲
つくすt #KJ*5 盡
つくるt #KJ*13 作
つくるt #KJ*13 造
つくるt #KJ*5 做
つくるt #KJ*5 爲
つくろうt #KJ*11 繕
つぐt #KJ*13 接
つぐt #KJ*13 次
つぐt #KJ*11 継
つぐt #KJ*5 亞
つぐt #KJ*5 繼
つぐt #KJ*5 韶
つぐなうt #KJ*11 償
つぐむt #KJ*5 噤
つけt #KJ*9 漬
つけるt #KJ*13 付
つけるt #KJ*13 就
つけるt #KJ*13 着
つけるt #KJ*9 漬
つげるt #KJ*13 告
つげるt #KJ*5 誥
つたうt #KJ*13 伝
つたうt #KJ*5 傳
つたえるt #KJ*13 伝
つたえるt #KJ*5 傳
つたわるt #KJ*13 伝
つたわるt #KJ*5 傳
つちかうt #KJ*11 培
つつしみt #KJ*5 愼
つつしむt #KJ*11 慎
つつしむt #KJ*11 謹
つつしむt #KJ*7 欽
つつしむt #KJ*5 兢
つつしむt #KJ*5 恪
つつしむt #KJ*5 愨
つつしむt #KJ*5 愼
つつしむt #KJ*5 愿
つつしむt #KJ*5 祗
つつしむt #KJ*5 竦
つつしむt #KJ*5 肅
つつしむt #KJ*5 虔
つつましいt #KJ*5 儉
つつむt #KJ*13 包
つつむt #KJ*5 勹
つつむt #KJ*5 裹
つづくt #KJ*13 続
つづくt #KJ*5 續
つづけるt #KJ*13 続
つづけるt #KJ*5 續
つづまやかt #KJ*5 儉
つづりt #KJ*7 綴
つづるt #KJ*7 綴
つとにt #KJ*7 夙
つとまるt #KJ*13 勤
つとめるt #KJ*13 努
つとめるt #KJ*13 務
つとめるt #KJ*13 勤
つとめるt #KJ*5 仂
つとめるt #KJ*5 劭
つとめるt #KJ*5 勗
つとめるt #KJ*5 懋
つとめるt #KJ*5 黽
つどうt #KJ*13 集
つなぐt #KJ*7 繋
つなぐt #KJ*5 絆
つなぐt #KJ*5 緤
つなぐt #KJ*5 羇
つなぐt #KJ*5 羈
つなぐt #KJ*5 覊
つねるt #KJ*5 抓
つのるt #KJ*11 募
つぶやくt #KJ*5 呟
つぶれt #KJ*7 潰
つまずくt #KJ*5 跌
つまずくt #KJ*5 蹉
つまずくt #KJ*5 蹶
つまずくt #KJ*5 躓
つまばさむt #KJ*5 襭
つまむt #KJ*5 抓
つまるt #KJ*11 詰
つむt #KJ*13 積
つむt #KJ*11 摘
つむt #KJ*11 詰
つむt #KJ*11 錘
つむt #KJ*5 薀
つむt #KJ*5 蘊
つむぐt #KJ*11 紡
つむぐt #KJ*5 緝
つめたいt #KJ*13 冷
つめるt #KJ*11 詰
つもるt #KJ*13 積
つよいt #KJ*13 強
つよいt #KJ*7 侃
つよいt #KJ*7 彊
つよいt #KJ*5 倔
つよいt #KJ*5 勁
つよいt #KJ*5 勍
つよいt #KJ*5 逎
つよいt #KJ*5 遒
つよまるt #KJ*13 強
つよめるt #KJ*13 強
つらなるt #KJ*13 連
つらなるt #KJ*7 聯
つらなるt #KJ*5 緜
つらなるt #KJ*5 聨
つらぬくt #KJ*11 貫
つらねるt #KJ*13 連
つらねるt #KJ*7 聯
つらねるt #KJ*5 聨
つらねるt #KJ*5 肆
つりt #KJ*9 釣
つりt #KJ*7 吊
つるt #KJ*9 釣
つるt #KJ*7 吊
つるすt #KJ*7 吊
つれるt #KJ*13 連
づくt #KJ*11 衝
てらうt #KJ*5 衒
てらすt #KJ*13 照
てるt #KJ*13 照
てれるt #KJ*13 照
でるt #KJ*13 出
といt #KJ*13 問
とうt #KJ*13 問
とうt #KJ*13 訪
とうt #KJ*7 訊
とうといt #KJ*13 尊
とうといt #KJ*13 貴
とうとぶt #KJ*13 尊
とうとぶt #KJ*13 貴
とおいt #KJ*13 遠
とおいt #KJ*5 茫
とおいt #KJ*5 藐
とおいt #KJ*5 逖
とおいt #KJ*5 遐
とおすt #KJ*13 通
とおりt #KJ*13 通
とおるt #KJ*13 通
とおるt #KJ*7 亨
とおるt #KJ*7 疏
とかすt #KJ*13 解
とかすt #KJ*11 溶
とかすt #KJ*5 爍
とかすt #KJ*5 觧
とかすt #KJ*5 鑠
とがめるt #KJ*5 咎
とがるt #KJ*7 尖
とくt #KJ*13 解
とくt #KJ*13 説
とくt #KJ*11 溶
とくt #KJ*5 梳
とくt #KJ*5 觧
とくt #KJ*5 釋
とぐt #KJ*13 研
とけるt #KJ*13 解
とけるt #KJ*11 溶
とけるt #KJ*5 觧
とけるt #KJ*5 銷
とげるt #KJ*11 遂
とざすt #KJ*13 閉
とざすt #KJ*5 閇
とじるt #KJ*13 閉
とじるt #KJ*5 緘
とじるt #KJ*5 閇
とつぐt #KJ*11 嫁
とつぐt #KJ*5 歸
とつぐt #KJ*5 皈
とてもt #KJ*5 迚
ととのうt #KJ*13 整
ととのうt #KJ*13 調
ととのうt #KJ*5 齊
ととのえるt #KJ*13 整
ととのえるt #KJ*13 調
とどくt #KJ*13 届
とどくt #KJ*5 屆
とどけt #KJ*5 屆
とどけるt #KJ*13 届
とどけるt #KJ*5 屆
とどこおるt #KJ*11 滞
とどこおるt #KJ*5 滯
とどまるt #KJ*7 逗
とどまるt #KJ*5 渟
とどまるt #KJ*5 畄
とどめるt #KJ*5 畄
とどめるt #KJ*5 遏
とどめるt #KJ*5 閼
とどろくt #KJ*7 轟
とどろくt #KJ*5 軣
となえるt #KJ*13 唱
となえるt #KJ*5 倡
となえるt #KJ*5 徇
となえるt #KJ*5 稱
となえるt #KJ*5 誦
となるt #KJ*11 隣
とばすt #KJ*13 飛
とぶt #KJ*13 飛
とぶt #KJ*11 跳
とぶt #KJ*5 翔
とぼしいt #KJ*11 乏
とまるt #KJ*13 止
とまるt #KJ*13 留
とまるt #KJ*11 泊
とまるt #KJ*5 畄
とみにt #KJ*7 頓
とむt #KJ*13 富
とむt #KJ*7 冨
とむらうt #KJ*11 弔
とめるt #KJ*13 止
とめるt #KJ*13 留
とめるt #KJ*11 泊
とめるt #KJ*5 畄
ともすt #KJ*11 燈
ともなうt #KJ*11 伴
ともにt #KJ*7 倶
ともにt #KJ*5 偕
ともにt #KJ*5 與
とらえるt #KJ*11 捕
とらえるt #KJ*7 捉
とらえるt #KJ*5 擒
とらわれるt #KJ*11 捕
とるt #KJ*13 取
とるt #KJ*13 採
とるt #KJ*11 執
とるt #KJ*11 捕
とるt #KJ*11 撮
とるt #KJ*5 搏
とるt #KJ*5 搴
とるt #KJ*5 攝
とるt #KJ*5 攬
とるt #KJ*5 秉
どもるt #KJ*7 吃
どもるt #KJ*5 吶
どもるt #KJ*5 訥
どもるt #KJ*5 謇
ないt #KJ*13 亡
ないt #KJ*13 無
ないt #KJ*5 沒
ないt #KJ*5 罔
ないt #KJ*5 靡
ないがしろt #KJ*7 蔑
なうt #KJ*5 綯
なえるt #KJ*7 萎
なえるt #KJ*5 痿
なおすt #KJ*13 治
なおすt #KJ*13 直
なおるt #KJ*13 治
なおるt #KJ*13 直
なかばt #KJ*13 半
なかれt #KJ*7 勿
なかれt #KJ*7 莫
なかれt #KJ*5 毋
ながいt #KJ*13 永
ながいt #KJ*13 長
ながいt #KJ*5 曼
ながいt #KJ*5 脩
ながすt #KJ*13 流
ながめるt #KJ*9 眺
ながらt #KJ*7 乍
ながれるt #KJ*13 流
なくt #KJ*13 泣
なくt #KJ*13 鳴
なくt #KJ*5 哭
なくt #KJ*5 啼
なくt #KJ*5 啾
なくt #KJ*5 嚶
なくt #KJ*5 涕
なぐt #KJ*7 凪
なぐt #KJ*7 薙
なぐさむt #KJ*11 慰
なぐさめるt #KJ*11 慰
なぐるt #KJ*11 殴
なぐるt #KJ*5 毆
なげうつt #KJ*5 抛
なげうつt #KJ*5 擲
なげかわしいt #KJ*11 嘆
なげくt #KJ*11 嘆
なげくt #KJ*11 慨
なげくt #KJ*7 歎
なげくt #KJ*5 喟
なげくt #KJ*5 嗟
なげくt #KJ*5 慟
なげくt #KJ*5 欷
なげるt #KJ*13 投
なごむt #KJ*13 和
なごやかt #KJ*13 和
なさけt #KJ*13 情
なしt #KJ*7 勿
なすt #KJ*13 成
なすt #KJ*5 做
なすt #KJ*5 濟
なすt #KJ*5 爲
なぞらえるt #KJ*5 凖
なだめるt #KJ*7 宥
なつかしいt #KJ*11 懐
なつかしいt #KJ*5 懷
なつかしむt #KJ*11 懐
なつかしむt #KJ*5 懷
なつくt #KJ*11 懐
なつくt #KJ*5 懷
なつけるt #KJ*11 懐
なつけるt #KJ*5 懷
なでるt #KJ*7 撫
なでるt #KJ*5 拊
なでるt #KJ*5 捫
ななつt #KJ*13 七
ななめt #KJ*11 斜
なびくt #KJ*5 靡
なぶるt #KJ*5 嬲
なまぐさいt #KJ*5 羶
なまぐさいt #KJ*5 腥
なまけるt #KJ*11 怠
なまじいにt #KJ*5 憖
なまめかしいt #KJ*5 嬌
なまるt #KJ*5 訛
なまるt #KJ*5 譌
なめらかt #KJ*11 滑
なめるt #KJ*7 嘗
なめるt #KJ*5 甞
なめるt #KJ*5 舐
なやますt #KJ*11 悩
なやますt #KJ*5 惱
なやむt #KJ*11 悩
なやむt #KJ*5 惱
なやむt #KJ*5 懊
なやむt #KJ*5 艱
ならうt #KJ*13 習
ならうt #KJ*11 倣
ならうt #KJ*5 傚
ならうt #KJ*5 嫺
ならうt #KJ*5 嫻
ならうt #KJ*5 效
ならうt #KJ*5 狃
ならうt #KJ*5 肄
ならすt #KJ*13 慣
ならすt #KJ*13 鳴
ならすt #KJ*7 馴
ならびにt #KJ*13 並
ならびにt #KJ*5 竝
ならぶt #KJ*13 並
ならぶt #KJ*5 伉
ならぶt #KJ*5 儷
ならぶt #KJ*5 并
ならぶt #KJ*5 竝
ならぶt #KJ*5 雙
ならぶt #KJ*5 駢
ならべるt #KJ*13 並
ならべるt #KJ*5 并
ならべるt #KJ*5 竝
ならべるt #KJ*5 駢
なるt #KJ*13 成
なるt #KJ*13 鳴
なれt #KJ*7 馴
なれるt #KJ*13 慣
なれるt #KJ*7 馴
なれるt #KJ*5 狃
なれるt #KJ*5 狎
なれるt #KJ*5 褻
なんぞt #KJ*7 渠
なんぞt #KJ*7 胡
なんぞt #KJ*5 奚
なんぞt #KJ*5 瑕
なんぞt #KJ*5 盍
なんぞt #KJ*5 遐
なんなんとするt #KJ*5 埀
にえるt #KJ*11 煮
においt #KJ*7 匂
におうt #KJ*7 匂
にがいt #KJ*13 苦
にがすt #KJ*11 逃
にがすt #KJ*5 迯
にがるt #KJ*13 苦
にぎやかt #KJ*7 賑
にぎるt #KJ*11 握
にぎわいt #KJ*7 賑
にぎわうt #KJ*7 賑
にぎわすt #KJ*7 賑
にくいt #KJ*11 憎
にくしみt #KJ*11 憎
にくむt #KJ*11 憎
にくむt #KJ*7 嫉
にくむt #KJ*5 惡
にくらしいt #KJ*11 憎
にげるt #KJ*11 逃
にげるt #KJ*5 迯
にごすt #KJ*11 濁
にごるt #KJ*11 濁
にごるt #KJ*5 渾
にごるt #KJ*5 溷
にじるt #KJ*5 躙
にじるt #KJ*5 躪
になうt #KJ*13 担
になうt #KJ*5 擔
にぶいt #KJ*11 鈍
にぶいt #KJ*5 駑
にぶるt #KJ*11 鈍
にやすt #KJ*11 煮
にらぐt #KJ*5 淬
にらむt #KJ*5 盻
にらむt #KJ*5 睨
にるt #KJ*13 似
にるt #KJ*11 煮
にるt #KJ*7 烹
にるt #KJ*7 煎
にわかt #KJ*5 遽
にわかt #KJ*5 驟
にわかにt #KJ*7 勃
にわかにt #KJ*5 卆
ぬうt #KJ*11 縫
ぬかすt #KJ*11 抜
ぬかすt #KJ*5 拔
ぬかるt #KJ*11 抜
ぬかるt #KJ*5 倥
ぬかるt #KJ*5 拔
ぬかるt #KJ*5 濘
ぬきんでるt #KJ*7 擢
ぬくt #KJ*11 抜
ぬくt #KJ*5 拔
ぬくt #KJ*5 搴
ぬくt #KJ*5 繹
ぬぐt #KJ*11 脱
ぬぐt #KJ*5 褪
ぬぐいt #KJ*7 拭
ぬぐうt #KJ*7 拭
ぬぐうt #KJ*5 揩
ぬけるt #KJ*11 抜
ぬけるt #KJ*5 拔
ぬげるt #KJ*11 脱
ぬすむt #KJ*11 盗
ぬすむt #KJ*5 偸
ぬすむt #KJ*5 攘
ぬすむt #KJ*5 盜
ぬすむt #KJ*5 竊
ぬらすt #KJ*7 濡
ぬるt #KJ*11 塗
ぬれt #KJ*7 濡
ぬれるt #KJ*7 濡
ねかすt #KJ*11 寝
ねかすt #KJ*5 寢
ねがうt #KJ*13 願
ねがうt #KJ*5 覦
ねぎらうt #KJ*5 勞
ねぎらうt #KJ*5 犒
ねじるt #KJ*5 捩
ねたむt #KJ*7 妬
ねたむt #KJ*7 嫉
ねばるt #KJ*11 粘
ねばるt #KJ*5 黏
ねむいt #KJ*11 眠
ねむるt #KJ*11 眠
ねらうt #KJ*7 狙
ねるt #KJ*13 練
ねるt #KJ*11 寝
ねるt #KJ*7 煉
ねるt #KJ*5 寢
ねんごろt #KJ*11 懇
のがすt #KJ*11 逃
のがすt #KJ*5 迯
のがれるt #KJ*11 逃
のがれるt #KJ*7 遁
のがれるt #KJ*5 佚
のがれるt #KJ*5 竄
のがれるt #KJ*5 迯
のがれるt #KJ*5 逋
のがれるt #KJ*5 遯
のこすt #KJ*13 残
のこすt #KJ*5 殘
のこりt #KJ*5 殘
のこるt #KJ*13 残
のこるt #KJ*5 殘
のすt #KJ*5 熨
のせるt #KJ*13 乗
のせるt #KJ*11 載
のせるt #KJ*5 乘
のぞきt #KJ*7 覗
のぞくt #KJ*13 除
のぞくt #KJ*7 覗
のぞくt #KJ*5 覘
のぞむt #KJ*13 望
のぞむt #KJ*13 臨
のぞむt #KJ*5 莅
のたまわくt #KJ*5 曰
のっとるt #KJ*5 糢
ののしるt #KJ*7 罵
ののしるt #KJ*5 詈
のばすt #KJ*13 延
のばすt #KJ*11 伸
のびるt #KJ*13 延
のびるt #KJ*11 伸
のびるt #KJ*7 暢
のべるt #KJ*13 延
のべるt #KJ*13 述
のべるt #KJ*5 抒
のべるt #KJ*5 敍
のべるt #KJ*5 敘
のべるt #KJ*5 舒
のぼすt #KJ*13 上
のぼせるt #KJ*13 上
のぼるt #KJ*13 上
のぼるt #KJ*13 登
のぼるt #KJ*11 昇
のぼるt #KJ*5 躋
のぼるt #KJ*5 陞
のぼるt #KJ*5 陟
のぼるt #KJ*5 隲
のむt #KJ*13 飲
のむt #KJ*7 呑
のむt #KJ*7 咽
のむt #KJ*5 嚥
のむt #KJ*5 飮
のるt #KJ*13 乗
のるt #KJ*11 載
のるt #KJ*5 乘
のろいt #KJ*7 呪
のろいt #KJ*5 咒
のろうt #KJ*7 呪
のろうt #KJ*5 咒
のろうt #KJ*5 詛
はいt #KJ*7 這
はいるt #KJ*13 入
はうt #KJ*7 這
はうt #KJ*5 匍
はえt #KJ*13 栄
はえt #KJ*5 榮
はえるt #KJ*13 映
はえるt #KJ*13 栄
はえるt #KJ*13 生
はえるt #KJ*5 暎
はえるt #KJ*5 榮
はかどるt #KJ*7 捗
はかないt #KJ*5 儚
はかなむt #KJ*5 儚
はからうt #KJ*13 計
はかるt #KJ*13 図
はかるt #KJ*13 測
はかるt #KJ*13 計
はかるt #KJ*13 量
はかるt #KJ*11 諮
はかるt #KJ*11 謀
はかるt #KJ*7 諏
はかるt #KJ*5 仞
はかるt #KJ*5 仭
はかるt #KJ*5 咨
はかるt #KJ*5 圖
はかるt #KJ*5 忖
はかるt #KJ*5 揆
はかるt #KJ*5 揣
はかるt #KJ*5 權
はかるt #KJ*5 畧
はかるt #KJ*5 畫
はかるt #KJ*5 稱
はかるt #KJ*5 詢
はかるt #KJ*5 謨
はかるt #KJ*5 銓
はがれるt #KJ*7 剥
はぎt #KJ*7 矧
はくt #KJ*11 吐
はくt #KJ*11 履
はくt #KJ*11 掃
はくt #KJ*5 咯
はくt #KJ*5 嘔
はくt #KJ*5 歐
はぐt #KJ*7 剥
はぐt #KJ*7 矧
はぐくむt #KJ*5 孚
はぐくむt #KJ*5 毓
はけt #KJ*7 捌
はけるt #KJ*7 捌
はげしいt #KJ*13 激
はげますt #KJ*11 励
はげますt #KJ*5 勵
はげむt #KJ*11 励
はげむt #KJ*5 勵
はげるt #KJ*7 剥
はげるt #KJ*7 禿
はこぶt #KJ*13 運
はこぶt #KJ*5 轉
はさまるt #KJ*9 挟
はさまるt #KJ*5 挾
はさむt #KJ*9 挟
はさむt #KJ*5 夾
はさむt #KJ*5 挾
はさむt #KJ*5 箝
はしるt #KJ*13 走
はしるt #KJ*5 犇
はしるt #KJ*5 赱
はしるt #KJ*5 迸
はしるt #KJ*5 驟
はじくt #KJ*5 彈
はじまるt #KJ*13 始
はじめt #KJ*13 初
はじめt #KJ*13 始
はじめt #KJ*7 孟
はじめt #KJ*7 甫
はじめt #KJ*7 肇
はじめt #KJ*5 俶
はじめt #KJ*5 弌
はじめてt #KJ*13 初
はじめるt #KJ*13 始
はじめるt #KJ*7 肇
はじめるt #KJ*5 剏
はじらうt #KJ*11 恥
はじらうt #KJ*5 耻
はじるt #KJ*11 恥
はじるt #KJ*5 忸
はじるt #KJ*5 愧
はじるt #KJ*5 慙
はじるt #KJ*5 慚
はじるt #KJ*5 耻
はずかしいt #KJ*11 恥
はずかしいt #KJ*5 耻
はずかしめるt #KJ*11 辱
はずかしめるt #KJ*5 詬
はずすt #KJ*13 外
はずむt #KJ*11 弾
はずむt #KJ*5 彈
はずれるt #KJ*13 外
はせるt #KJ*7 馳
はせるt #KJ*7 駈
はせるt #KJ*5 駛
はせるt #KJ*5 騁
はせるt #KJ*5 驅
はたすt #KJ*13 果
はたとt #KJ*5 礑
はたらくt #KJ*13 働
はてt #KJ*13 果
はてるt #KJ*13 果
はなすt #KJ*13 放
はなすt #KJ*13 話
はなすt #KJ*11 離
はなつt #KJ*13 放
はなつt #KJ*5 發
はなつt #KJ*5 縱
はなはだt #KJ*9 甚
はなはだt #KJ*5 已
はなはだしいt #KJ*9 甚
はなれるt #KJ*13 放
はなれるt #KJ*11 離
はねるt #KJ*11 跳
はねるt #KJ*5 撥
はばかりt #KJ*5 憚
はばかるt #KJ*5 憚
はばむt #KJ*11 阻
はばむt #KJ*5 沮
はびこるt #KJ*5 滔
はびこるt #KJ*5 衍
はぶくt #KJ*13 省
はめるt #KJ*7 填
はやいt #KJ*13 早
はやいt #KJ*13 速
はやいt #KJ*7 夙
はやいt #KJ*7 捷
はやいt #KJ*5 湍
はやいt #KJ*5 駛
はやすt #KJ*13 生
はやすt #KJ*5 囃
はやまるt #KJ*13 早
はやめるt #KJ*13 早
はやめるt #KJ*13 速
はやるt #KJ*11 逸
はらいt #KJ*5 祓
はらうt #KJ*11 払
はらうt #KJ*5 拂
はらうt #KJ*5 攘
はらうt #KJ*5 祓
はらうt #KJ*5 禊
はらうt #KJ*5 禳
はらうt #KJ*5 襄
はらすt #KJ*13 晴
はらみt #KJ*5 胚
はらむt #KJ*5 姙
はらむt #KJ*5 孕
はらむt #KJ*5 胚
はりt #KJ*7 貼
はるt #KJ*13 張
はるt #KJ*7 貼
はるかt #KJ*7 遥
はるかt #KJ*7 遼
はるかt #KJ*5 夐
はるかt #KJ*5 杳
はるかt #KJ*5 迥
はるかt #KJ*5 遙
はれるt #KJ*13 晴
はれるt #KJ*5 霽
ばかすt #KJ*13 化
ばけるt #KJ*13 化
ひいでるt #KJ*11 秀
ひえるt #KJ*13 冷
ひかえるt #KJ*11 控
ひかえるt #KJ*5 扣
ひかるt #KJ*13 光
ひかるt #KJ*5 煕
ひかるt #KJ*5 熈
ひかるt #KJ*5 熙
ひがむt #KJ*7 僻
ひきいるt #KJ*13 率
ひきいるt #KJ*5 將
ひきつるt #KJ*5 痙
ひくt #KJ*13 引
ひくt #KJ*11 弾
ひくt #KJ*7 惹
ひくt #KJ*7 挽
ひくt #KJ*7 曳
ひくt #KJ*7 牽
ひくt #KJ*5 弯
ひくt #KJ*5 彈
ひくt #KJ*5 彎
ひくt #KJ*5 拏
ひくt #KJ*5 拿
ひくt #KJ*5 掎
ひくt #KJ*5 掣
ひくt #KJ*5 攣
ひくt #KJ*5 曵
ひくt #KJ*5 碾
ひくt #KJ*5 輓
ひくいt #KJ*13 低
ひくいt #KJ*5 矮
ひくまるt #KJ*13 低
ひくめるt #KJ*13 低
ひけるt #KJ*13 引
ひさぐt #KJ*7 粥
ひさぐt #KJ*5 鬻
ひさしいt #KJ*13 久
ひざまずくt #KJ*5 跪
ひしめくt #KJ*5 犇
ひずむt #KJ*7 歪
ひそかt #KJ*5 祕
ひそかにt #KJ*5 潛
ひそかにt #KJ*5 濳
ひそかにt #KJ*5 竊
ひそむt #KJ*11 潜
ひそむt #KJ*5 潛
ひそむt #KJ*5 濳
ひそめるt #KJ*5 顰
ひたすt #KJ*11 浸
ひたすt #KJ*5 涵
ひたすt #KJ*5 溲
ひたるt #KJ*11 浸
ひっさげるt #KJ*5 挈
ひとしいt #KJ*13 等
ひとしいt #KJ*5 凖
ひとしいt #KJ*5 畴
ひとしいt #KJ*5 疇
ひとしいt #KJ*5 鈞
ひとしいt #KJ*5 齊
ひとつt #KJ*13 一
ひとつt #KJ*5 壹
ひとつt #KJ*5 弌
ひとりt #KJ*13 独
ひとりt #KJ*5 獨
ひねるt #KJ*7 捻
ひねるt #KJ*7 撚
ひねるt #KJ*5 拈
ひびきt #KJ*11 響
ひびくt #KJ*11 響
ひめるt #KJ*13 秘
ひめるt #KJ*5 祕
ひもとくt #KJ*5 繙
ひやかすt #KJ*13 冷
ひやすt #KJ*13 冷
ひらくt #KJ*13 開
ひらくt #KJ*5 拆
ひらくt #KJ*5 擺
ひらくt #KJ*5 攤
ひらくt #KJ*5 辟
ひらくt #KJ*5 闢
ひらけるt #KJ*13 開
ひらけるt #KJ*5 豁
ひらめくt #KJ*7 閃
ひるt #KJ*13 干
ひるがえすt #KJ*11 翻
ひるがえすt #KJ*5 飜
ひるがえるt #KJ*11 翻
ひるがえるt #KJ*5 翩
ひるがえるt #KJ*5 飜
ひろいt #KJ*13 博
ひろいt #KJ*13 広
ひろいt #KJ*11 寛
ひろいt #KJ*7 宏
ひろいt #KJ*7 汎
ひろいt #KJ*7 浩
ひろいt #KJ*5 廣
ひろいt #KJ*5 滉
ひろいt #KJ*5 濶
ひろいt #KJ*5 瀚
ひろいt #KJ*5 煕
ひろいt #KJ*5 熈
ひろいt #KJ*5 熙
ひろいt #KJ*5 絋
ひろいt #KJ*5 豁
ひろいt #KJ*5 闊
ひろうt #KJ*13 拾
ひろがるt #KJ*13 広
ひろがるt #KJ*7 氾
ひろがるt #KJ*5 廣
ひろげるt #KJ*13 広
ひろげるt #KJ*5 廣
ひろげるt #KJ*5 擴
ひろまるt #KJ*13 広
ひろまるt #KJ*5 廣
ひろむt #KJ*7 弘
ひろめるt #KJ*13 広
ひろめるt #KJ*7 弘
ひろめるt #KJ*5 廣
ふえるt #KJ*13 増
ふえるt #KJ*11 殖
ふかいt #KJ*13 深
ふかいt #KJ*5 泓
ふかいt #KJ*5 潭
ふかいt #KJ*5 邃
ふかすt #KJ*11 更
ふかまるt #KJ*13 深
ふかめるt #KJ*13 深
ふくt #KJ*11 吹
ふくt #KJ*11 噴
ふくt #KJ*7 拭
ふくt #KJ*7 葺
ふくむt #KJ*11 含
ふくむt #KJ*5 哺
ふくめるt #KJ*11 含
ふくらむt #KJ*11 膨
ふくれるt #KJ*11 膨
ふけるt #KJ*13 老
ふけるt #KJ*11 更
ふけるt #KJ*7 耽
ふけるt #KJ*5 酖
ふさがるt #KJ*5 阨
ふさぐt #KJ*7 塞
ふさぐt #KJ*7 填
ふさぐt #KJ*5 堙
ふさぐt #KJ*5 壅
ふさぐt #KJ*5 沍
ふさぐt #KJ*5 湮
ふさぐt #KJ*5 錮
ふさぐt #KJ*5 閼
ふさぐt #KJ*5 雍
ふすt #KJ*11 伏
ふすt #KJ*7 臥
ふすべるt #KJ*5 熏
ふすべるt #KJ*5 燻
ふせぐt #KJ*13 防
ふせぐt #KJ*7 禦
ふせぐt #KJ*5 扞
ふせぐt #KJ*5 捍
ふせるt #KJ*11 伏
ふせるt #KJ*7 臥
ふせるt #KJ*5 俛
ふせるt #KJ*5 俯
ふせるt #KJ*5 偃
ふたたびt #KJ*13 再
ふたつt #KJ*13 二
ふたつt #KJ*5 兩
ふたつt #KJ*5 弍
ふたつt #KJ*5 貮
ふたつt #KJ*5 貳
ふたつt #KJ*5 雙
ふといt #KJ*13 太
ふとるt #KJ*13 太
ふまえるt #KJ*11 踏
ふむt #KJ*11 踏
ふむt #KJ*5 藉
ふむt #KJ*5 跋
ふむt #KJ*5 踐
ふむt #KJ*5 蹈
ふむt #KJ*5 躙
ふむt #KJ*5 躡
ふむt #KJ*5 躪
ふやすt #KJ*13 増
ふやすt #KJ*11 殖
ふるt #KJ*13 降
ふるt #KJ*11 振
ふるいt #KJ*13 古
ふるいt #KJ*5 舊
ふるうt #KJ*13 奮
ふるうt #KJ*11 振
ふるうt #KJ*11 震
ふるうt #KJ*5 掉
ふるえるt #KJ*11 震
ふるえるt #KJ*5 顫
ふるすt #KJ*13 古
ふれるt #KJ*11 触
ふれるt #KJ*5 牴
ふれるt #KJ*5 觝
ふれるt #KJ*5 觸
へだたるt #KJ*11 隔
へだてるt #KJ*11 隔
へだてるt #KJ*5 鬲
へつらいt #KJ*5 諛
へつらうt #KJ*5 諂
へつらうt #KJ*5 諛
へらすt #KJ*13 減
へるt #KJ*13 減
へるt #KJ*13 経
へるt #KJ*5 經
べしt #KJ*5 當
ほうむるt #KJ*11 葬
ほえt #KJ*7 吠
ほえるt #KJ*7 吠
ほえるt #KJ*5 吼
ほえるt #KJ*5 咆
ほえるt #KJ*5 哮
ほがらかt #KJ*13 朗
ほがらかt #KJ*5 敞
ほがらかt #KJ*5 朖
ほこるt #KJ*11 誇
ほこるt #KJ*5 矜
ほころびるt #KJ*7 綻
ほしいt #KJ*13 欲
ほすt #KJ*13 干
ほそいt #KJ*13 細
ほそいt #KJ*5 纎
ほそいt #KJ*5 纖
ほそるt #KJ*13 細
ほっするt #KJ*13 欲
ほとばしるt #KJ*5 迸
ほとんどt #KJ*7 殆
ほどこすt #KJ*11 施
ほふるt #KJ*7 屠
ほまれt #KJ*11 誉
ほまれt #KJ*5 譽
ほめるt #KJ*9 褒
ほめるt #KJ*7 讃
ほめるt #KJ*5 稱
ほめるt #KJ*5 襃
ほめるt #KJ*5 讚
ほめるt #KJ*5 頌
ほるt #KJ*11 彫
ほるt #KJ*11 掘
ほるt #KJ*5 鐫
ほれるt #KJ*7 惚
ほろびるt #KJ*11 滅
ほろびるt #KJ*5 泯
ほろぼすt #KJ*11 滅
ほろぼすt #KJ*5 殱
ほろぼすt #KJ*5 殲
ぼかすt #KJ*5 暈
まいるt #KJ*13 参
まいるt #KJ*5 參
まうt #KJ*11 舞
まかすt #KJ*13 任
まかすt #KJ*13 負
まかせるt #KJ*13 任
まかなうt #KJ*11 賄
まがるt #KJ*13 曲
まがるt #KJ*5 枉
まがるt #KJ*5 紆
まぎらすt #KJ*11 紛
まぎらわしいt #KJ*11 紛
まぎらわすt #KJ*11 紛
まぎれるt #KJ*11 紛
まくt #KJ*13 巻
まくt #KJ*7 捲
まくt #KJ*7 撒
まくt #KJ*7 播
まくt #KJ*7 蒔
まくt #KJ*5 卷
まくt #KJ*5 繃
まけるt #KJ*13 負
まげてt #KJ*5 枉
まげるt #KJ*13 曲
まげるt #KJ*5 枉
まことにt #KJ*7 允
まことにt #KJ*7 諒
まことにt #KJ*5 寔
まことにt #KJ*5 洵
まさにt #KJ*13 将
まさにt #KJ*7 祇
まさにt #KJ*5 夛
まさにt #KJ*5 將
まさにt #KJ*5 當
まさるt #KJ*13 勝
まざるt #KJ*13 交
まざるt #KJ*13 混
まじえるt #KJ*13 交
まじえるt #KJ*5 襍
まじえるt #KJ*5 雜
まじるt #KJ*13 交
まじるt #KJ*13 混
まじるt #KJ*5 淆
まじるt #KJ*5 糅
まじるt #KJ*5 襍
まじるt #KJ*5 雜
まじわるt #KJ*13 交
まじわるt #KJ*5 參
まじわるt #KJ*5 爻
ますt #KJ*13 増
まずしいt #KJ*13 貧
まぜるt #KJ*13 交
まぜるt #KJ*13 混
またがるt #KJ*7 跨
またぐt #KJ*7 跨
またたくt #KJ*11 瞬
まったくt #KJ*13 全
まつt #KJ*13 待
まつt #KJ*7 須
まつt #KJ*5 俟
まつt #KJ*5 竢
まつt #KJ*5 遲
まつりt #KJ*5 祀
まつるt #KJ*13 祭
まつるt #KJ*5 奠
まつるt #KJ*5 祀
まつるt #KJ*5 祠
まとうt #KJ*7 纏
まとうt #KJ*5 綢
まとうt #KJ*5 繆
まとうt #KJ*5 繚
まとうt #KJ*5 繞
まとうt #KJ*5 纒
まどうt #KJ*11 惑
まどうt #KJ*5 眩
まなぶt #KJ*13 学
まなぶt #KJ*5 學
まなぶt #KJ*5 斈
まぬかれるt #KJ*11 免
まねくt #KJ*13 招
まばらt #KJ*5 踈
まみえるt #KJ*5 覲
まみえるt #KJ*5 逅
まみえるt #KJ*5 遘
まもりt #KJ*5 戍
まもるt #KJ*13 守
まもるt #KJ*5 戍
まもるt #KJ*5 衞
まようt #KJ*13 迷
まるいt #KJ*13 丸
まるいt #KJ*13 円
まるいt #KJ*5 圓
まるいt #KJ*5 團
まるいt #KJ*5 圜
まるいt #KJ*5 摶
まるめるt #KJ*13 丸
まわすt #KJ*13 回
まわすt #KJ*5 囘
まわりt #KJ*13 周
まわるt #KJ*13 回
まわるt #KJ*7 廻
まわるt #KJ*5 囘
みえるt #KJ*13 見
みがくt #KJ*9 磨
みがくt #KJ*7 琢
みがくt #KJ*7 瑳
みがくt #KJ*7 砺
みがくt #KJ*5 磋
みがくt #KJ*5 礪
みじかいt #KJ*13 短
みじめt #KJ*11 惨
みじめt #KJ*5 慘
みずからt #KJ*13 自
みせるt #KJ*13 見
みたすt #KJ*13 満
みたすt #KJ*5 滿
みだすt #KJ*13 乱
みだすt #KJ*7 撹
みだすt #KJ*5 亂
みだすt #KJ*5 撓
みだすt #KJ*5 攪
みだりにt #KJ*5 叨
みだりにt #KJ*5 猥
みだれるt #KJ*13 乱
みだれるt #KJ*7 擾
みだれるt #KJ*5 亂
みだれるt #KJ*5 撓
みだれるt #KJ*5 溷
みだれるt #KJ*5 紊
みだれるt #KJ*5 紜
みちびくt #KJ*13 導
みちるt #KJ*13 満
みちるt #KJ*7 塞
みちるt #KJ*7 溢
みちるt #KJ*7 盈
みちるt #KJ*5 實
みちるt #KJ*5 滿
みっつt #KJ*13 三
みつt #KJ*13 三
みつt #KJ*5 參
みつぐt #KJ*11 貢
みとめるt #KJ*13 認
みなぎるt #KJ*5 漲
みにくいt #KJ*11 醜
みのりt #KJ*7 稔
みのるt #KJ*13 実
みのるt #KJ*7 稔
みのるt #KJ*5 實
みはるt #KJ*5 瞠
みまかるt #KJ*5 薨
みみきるt #KJ*5 馘
みめよいt #KJ*5 娥
みやびやかt #KJ*5 嫺
みやびやかt #KJ*5 嫻
みるt #KJ*13 見
みるt #KJ*11 診
みるt #KJ*5 睹
みるt #KJ*5 瞰
みるt #KJ*5 瞻
みるt #KJ*5 瞿
みるt #KJ*5 矚
みるt #KJ*5 覩
みるt #KJ*5 覽
みるt #KJ*5 觀
むかうt #KJ*13 向
むかうt #KJ*5 嚮
むかうt #KJ*5 對
むかえるt #KJ*11 迎
むかえるt #KJ*7 這
むかえるt #KJ*7 逢
むかえるt #KJ*5 邀
むくt #KJ*13 向
むくt #KJ*7 剥
むくいるt #KJ*13 報
むけるt #KJ*13 向
むこうt #KJ*13 向
むさぼるt #KJ*7 昧
むさぼるt #KJ*5 婪
むさぼるt #KJ*5 貪
むさぼるt #KJ*5 饕
むしあついt #KJ*5 溽
むしばむt #KJ*7 蝕
むしるt #KJ*5 毟
むすt #KJ*13 蒸
むすぶt #KJ*13 結
むずかしいt #KJ*13 難
むせぶt #KJ*7 咽
むせぶt #KJ*5 哽
むせぶt #KJ*5 噎
むちうつt #KJ*7 鞭
むちうつt #KJ*5 捶
むちうつt #KJ*5 撻
むっつt #KJ*13 六
むつt #KJ*13 六
むつぶt #KJ*7 睦
むつまじいt #KJ*7 睦
むなしいt #KJ*5 冲
むなしいt #KJ*5 昿
むなしいt #KJ*5 曠
むらがるt #KJ*13 群
むらがるt #KJ*7 叢
むらがるt #KJ*5 簇
むらすt #KJ*13 蒸
むれt #KJ*5 羣
むれるt #KJ*13 群
むれるt #KJ*13 蒸
むれるt #KJ*5 羣
めぐむt #KJ*11 恵
めぐむt #KJ*5 惠
めぐりt #KJ*7 廻
めぐるt #KJ*11 巡
めぐるt #KJ*7 廻
めぐるt #KJ*7 斡
めぐるt #KJ*5 匯
めぐるt #KJ*5 圜
めぐるt #KJ*5 紆
めぐるt #KJ*5 繚
めぐるt #KJ*5 繞
めぐるt #KJ*5 轉
めぐるt #KJ*5 遶
めぐるt #KJ*5 邏
めすt #KJ*11 召
めすt #KJ*5 辟
めずらしいt #KJ*11 珍
めずらしいt #KJ*5 珎
めずらしいt #KJ*5 竒
めとるt #KJ*5 娶
めばえt #KJ*7 萌
めばえt #KJ*5 萠
もうけt #KJ*7 儲
もうけるt #KJ*13 設
もうすt #KJ*13 申
もうでるt #KJ*7 詣
もえるt #KJ*13 燃
もえるt #KJ*7 萌
もえるt #KJ*5 萠
もぐるt #KJ*11 潜
もぐるt #KJ*5 潛
もぐるt #KJ*5 濳
もしt #KJ*5 儻
もしくはt #KJ*13 若
もじるt #KJ*5 捩
もすt #KJ*13 燃
もたげるt #KJ*5 抬
もたげるt #KJ*5 擡
もたらすt #KJ*5 齎
もたれるt #KJ*5 凭
もだえt #KJ*7 悶
もだえるt #KJ*7 悶
もだえるt #KJ*5 懣
もだすt #KJ*5 默
もちいるt #KJ*13 用
もちいるt #KJ*7 須
もっともt #KJ*13 最
もっともt #KJ*7 尤
もっぱらt #KJ*13 専
もっぱらt #KJ*5 壹
もっぱらt #KJ*5 專
もつt #KJ*13 持
もつれt #KJ*5 縺
もつれるt #KJ*5 縺
もてあそぶt #KJ*7 弄
もてあそぶt #KJ*7 玩
もてあそぶt #KJ*7 翫
もとめるt #KJ*13 求
もとめるt #KJ*7 須
もとめるt #KJ*5 覓
もとめるt #KJ*5 邀
もとるt #KJ*5 乖
もとるt #KJ*5 剌
もとるt #KJ*5 很
もとるt #KJ*5 悖
もとるt #KJ*5 愎
もとるt #KJ*5 狠
もどすt #KJ*9 戻
もどるt #KJ*9 戻
ものういt #KJ*5 嬾
ものういt #KJ*5 慵
ものういt #KJ*5 懶
もむt #KJ*5 揉
もやすt #KJ*13 燃
もよおすt #KJ*11 催
もらいt #KJ*7 貰
もらうt #KJ*7 貰
もらすt #KJ*11 漏
もりt #KJ*13 盛
もるt #KJ*13 盛
もるt #KJ*11 漏
もれるt #KJ*11 漏
もれるt #KJ*7 洩
もれるt #KJ*5 泄
もろいt #KJ*7 脆
やがてt #KJ*5 軅
やがてt #KJ*5 軈
やくt #KJ*13 焼
やくt #KJ*7 灼
やくt #KJ*7 焚
やくt #KJ*5 烙
やくt #KJ*5 燒
やくt #KJ*5 燔
やくt #KJ*5 燬
やけるt #KJ*13 焼
やけるt #KJ*5 燒
やさしいt #KJ*13 優
やさしいt #KJ*13 易
やしなうt #KJ*13 養
やしなうt #KJ*5 毓
やすいt #KJ*13 安
やすいt #KJ*13 康
やすいt #KJ*11 泰
やすいt #KJ*7 靖
やすいt #KJ*5 恬
やすいt #KJ*5 綏
やすまるt #KJ*13 休
やすむt #KJ*13 休
やすめるt #KJ*13 休
やせるt #KJ*7 痩
やせるt #KJ*5 瘠
やっつt #KJ*13 八
やつt #KJ*13 八
やつれるt #KJ*5 忰
やつれるt #KJ*5 悴
やつれるt #KJ*5 憔
やつれるt #KJ*5 窶
やとうt #KJ*11 雇
やとうt #KJ*7 傭
やどすt #KJ*13 宿
やどるt #KJ*13 宿
やどるt #KJ*5 舍
やぶさかt #KJ*5 悋
やぶるt #KJ*13 破
やぶるt #KJ*5 毀
やぶるt #KJ*5 硅
やぶれるt #KJ*13 敗
やぶれるt #KJ*13 破
やぶれるt #KJ*5 壞
やぶれるt #KJ*5 敝
やましいt #KJ*5 疚
やむt #KJ*13 病
やむt #KJ*5 已
やむt #KJ*5 熄
やむt #KJ*5 疚
やめるt #KJ*13 辞
やめるt #KJ*5 歇
やめるt #KJ*5 輟
やめるt #KJ*5 辭
やわらかt #KJ*11 柔
やわらかt #KJ*11 軟
やわらかいt #KJ*11 柔
やわらかいt #KJ*11 軟
やわらぐt #KJ*13 和
やわらぐt #KJ*7 穆
やわらぐt #KJ*5 廱
やわらぐt #KJ*5 諧
やわらぐt #KJ*5 雍
やわらげるt #KJ*13 和
やわらげるt #KJ*5 燮
ゆうt #KJ*13 結
ゆがむt #KJ*7 歪
ゆくt #KJ*13 行
ゆくt #KJ*9 逝
ゆくt #KJ*7 之
ゆくt #KJ*5 徂
ゆくt #KJ*5 徃
ゆくt #KJ*5 邁
ゆさぶるt #KJ*11 揺
ゆさぶるt #KJ*5 搖
ゆすぶるt #KJ*11 揺
ゆすぶるt #KJ*5 搖
ゆするt #KJ*11 揺
ゆするt #KJ*5 搖
ゆずるt #KJ*11 譲
ゆずるt #KJ*5 禪
ゆずるt #KJ*5 讓
ゆたかt #KJ*11 裕
ゆたかt #KJ*7 穣
ゆたかt #KJ*5 穰
ゆたかt #KJ*5 胖
ゆたかt #KJ*5 豐
ゆたかt #KJ*5 饒
ゆでるt #KJ*5 茹
ゆらぐt #KJ*11 揺
ゆらぐt #KJ*5 搖
ゆるt #KJ*11 揺
ゆるt #KJ*5 搖
ゆるいt #KJ*11 緩
ゆるがせにするt #KJ*7 忽
ゆるぐt #KJ*11 揺
ゆるぐt #KJ*5 搖
ゆるすt #KJ*13 許
ゆるすt #KJ*7 恕
ゆるすt #KJ*5 縱
ゆるすt #KJ*5 聽
ゆるすt #KJ*5 釋
ゆるむt #KJ*11 緩
ゆるむt #KJ*7 弛
ゆるめるt #KJ*11 緩
ゆるやかt #KJ*11 緩
ゆれるt #KJ*11 揺
ゆれるt #KJ*5 搖
ゆわえるt #KJ*13 結
よいt #KJ*13 善
よいt #KJ*13 良
よいt #KJ*7 嘉
よいt #KJ*5 俶
よいt #KJ*5 懿
よいt #KJ*5 譱
ようt #KJ*11 酔
ようt #KJ*5 酊
ようt #KJ*5 酩
ようt #KJ*5 醉
ようt #KJ*5 醺
ようやくt #KJ*11 漸
ようやくt #KJ*5 稍
よごすt #KJ*11 汚
よごれるt #KJ*11 汚
よじるt #KJ*5 攀
よせるt #KJ*13 寄
よそおうt #KJ*13 装
よそおうt #KJ*5 妝
よそおうt #KJ*5 裝
よっつt #KJ*13 四
よつt #KJ*13 四
よどむt #KJ*7 淀
よどむt #KJ*7 澱
よなげるt #KJ*7 淘
よぶt #KJ*13 呼
よみがえるt #KJ*7 蘇
よみがえるt #KJ*5 甦
よみがえるt #KJ*5 蘓
よみするt #KJ*7 嘉
よむt #KJ*13 読
よむt #KJ*11 詠
よむt #KJ*5 誦
よむt #KJ*5 讀
よるt #KJ*13 因
よるt #KJ*13 寄
よるt #KJ*7 寓
よるt #KJ*7 撚
よるt #KJ*5 仍
よるt #KJ*5 仗
よるt #KJ*5 倚
よるt #KJ*5 凭
よるt #KJ*5 憑
よるt #KJ*5 搓
よるt #KJ*5 據
よるt #KJ*5 縒
よるt #KJ*5 靠
よるt #KJ*5 馮
よろこびt #KJ*5 憙
よろこぶt #KJ*13 喜
よろこぶt #KJ*7 欣
よろこぶt #KJ*5 僖
よろこぶt #KJ*5 忻
よろこぶt #KJ*5 怡
よろこぶt #KJ*5 憙
よろこぶt #KJ*5 懌
よろこぶt #KJ*5 懽
よろこぶt #KJ*5 歡
よろこぶt #KJ*5 煕
よろこぶt #KJ*5 熈
よろこぶt #KJ*5 熙
よろこぶt #KJ*5 驩
よわいt #KJ*13 弱
よわいt #KJ*5 孱
よわいt #KJ*5 懦
よわいt #KJ*5 羸
よわまるt #KJ*13 弱
よわめるt #KJ*13 弱
よわるt #KJ*13 弱
わかいt #KJ*13 若
わかいt #KJ*5 夭
わかいt #KJ*5 嫩
わかすt #KJ*11 沸
わかつt #KJ*13 分
わかるt #KJ*13 分
わかれt #KJ*7 訣
わかれるt #KJ*13 分
わかれるt #KJ*13 別
わかれるt #KJ*7 訣
わきまえるt #KJ*13 弁
わきまえるt #KJ*5 辧
わきまえるt #KJ*5 辨
わくt #KJ*11 沸
わくt #KJ*7 涌
わくt #KJ*7 湧
わくt #KJ*5 洶
わくt #KJ*5 滕
わけるt #KJ*13 分
わけるt #KJ*5 夬
わけるt #KJ*5 辧
わけるt #KJ*5 辨
わけるt #KJ*5 辯
わざわいt #KJ*13 災
わざわいt #KJ*5 殃
わすれるt #KJ*13 忘
わすれるt #KJ*5 諠
わずかt #KJ*7 僅
わずかt #KJ*5 纔
わずかにt #KJ*7 僅
わずらうt #KJ*11 患
わずらうt #KJ*11 煩
わずらわしいt #KJ*11 煩
わずらわしいt #KJ*7 擾
わずらわすt #KJ*11 煩
わたすt #KJ*11 渡
わたすt #KJ*5 濟
わたりt #KJ*7 亘
わたりt #KJ*7 亙
わたるt #KJ*11 渉
わたるt #KJ*11 渡
わたるt #KJ*7 亙
わたるt #KJ*5 亂
わたるt #KJ*5 濟
わたるt #KJ*5 竟
わだかまるt #KJ*5 蟠
わびしいt #KJ*5 侘
わびるt #KJ*7 詫
わびるt #KJ*5 佗
わびるt #KJ*5 侘
わらうt #KJ*13 笑
わらうt #KJ*5 听
わらうt #KJ*5 呵
わらうt #KJ*5 哂
わらうt #KJ*5 嗤
わるt #KJ*13 割
わるt #KJ*13 破
わるいt #KJ*13 悪
わるいt #KJ*5 惡
わるいt #KJ*5 獰
わるがしこいt #KJ*5 狡
わるがしこいt #KJ*5 猾
わるがしこいt #KJ*5 獪
われるt #KJ*13 割
