# Cannadicとは非互換の品詞を持つ辞書
#
# Anthyは一部の付属語を辞書に持つので
# cannadicに入っていない単語を書いています。
#
#
#てすつ #T35*100 A\ A
#まくる
#まわる
#
#
ちゅう #SVSUC*10 中
#しゃ #SVSUC*10 者
じ #SVSUC*10 時
#ご #SVSUC*10 後
#まえ #SVSUC*10 前
#ごと #SVSUC*10 ごと 毎
#き #SVSUC*10 機 器
#ずみ #SVSUC*10 済み
#りつ #SVSUC*10 率
#つ #JS つ
#かた #D2T35 方
#
\mofidy_freq がわ #T35 側 kill
がわ #SUC*250 側
\mofidy_freq かん #T35 間 kill
かん #SUC*250 間
ない #SUC*250 内
ごと #SUC*250 ごと #SUC*200 毎
#
#
いち #N04 一
に #N04 二
さん #N04 三
よん #N04 四
ご #N04 五
ろく #N04 六
なな #N04 七
はち #N04 八
きゅう #N04 九
#
ひゃく #N05 百
にひゃく #N05 二百
さんびゃく #N05 三百
よんひゃく #N05 四百
ごひゃく #N05 五百
ろっぴゃく #N05 六百
ななひゃく #N05 七百
はっぴゃく #N05 八百
きゅうひゃく #N05 九百
#
あそうぎ #N00 阿僧祇
ごうがしゃ #N00 恒河沙
なゆた #N00 那由多 那由他 奈由太
#
がた #D2KY 難 #D2KY*6 がた
づら #D2KY づら #D2KY*6 辛
やす #D2KY 易 #D2KY*645 やす
#
かんじが #SX 感じが
じ #JS*2 時
#
し #sxi2*400 し
くん #kxuru2*300 来ん
ね #KYE*300 ね
あち #KYI*150 あち
#
# その他
#
#
そうぞうだに #T30 想像だに
よそうだに #T30 予想だに
#
！ #KJ !
” #OPEN " #CLOSE "
#＃ #KJ # #は品詞と解釈されるのでエスケープする方法を考える
＄ #KJ $
％ #KJ %
＆ #KJ &
’ #KJ '
、 #KJ*10 、 ， , ，
ー #KJ -
。 #KJ 。 ． .
： #KJ :
； #KJ ;
＝ #KJ =
？ #KJ ?
＠ #KJ @
＼ #KJ \\ ￥
」 #KJ ]
＾ #KJ ^
＿ #KJ _
‘ #KJ `
｜ #KJ |
＜ #OPEN <
＞ #CLOSE >
（ #OPEN (
） #CLOSE )
｛ #OPEN {
｝ #CLOSE }
〜 #KJ ~
「 #OPEN 「 『 〈 《 【
」 #CLOSE 」 』 〉 》 】
。。。 #KJ …
％ #JS %
