/*
 * 前半は cannadic-0.90からコピーしてきた。
 * 後の方にAnthy独自の品詞が追加してある。
 */
/* リニアサーチで速く見付かるようによく使う品詞を先頭で定義する */
  /* カ変は#KXを使う */
{"#kxi",POS_V,COS_NONE,SCOS_NONE,CC_KV,CT_RENYOU,WF_INDEP   /* "カ変動詞(き)"*/},
{"#kxo",POS_V,COS_NONE,SCOS_NONE,CC_KV,CT_MIZEN,WF_INDEP   /* "カ変動詞(こ)"*/},
{"#kxoi",POS_V,COS_NONE,SCOS_NONE,CC_KV,CT_MEIREI,WF_INDEP  /* "カ変動詞(こい)"*/},
{"#kxure",POS_V,COS_NONE,SCOS_NONE,CC_KV,CT_KATEI,WF_INDEP /* "カ変動詞(くれ)"*/},
{"#kxuru",POS_V,COS_NONE,SCOS_NONE,CC_KV,CT_SYUSI,WF_INDEP /* "カ変動詞(くる)"*/},
{"#kxuru2",POS_V,COS_NONE,SCOS_NONE,CC_KV2,CT_SYUSI,WF_INDEP /* "カ変動詞(くん)"*/},
{"#kxya",POS_V,COS_NONE,SCOS_NONE,CC_KV2,CT_NONE,WF_INDEP  /* "カ変動詞(くりゃ)"*/},
  /* サ変「する」 */
{"#sxi",POS_V,COS_NONE,SCOS_NONE,CC_SRV,CT_MIZEN,WF_INDEP   /* "する未然形(し)"*/},
{"#sxe",POS_V,COS_NONE,SCOS_NONE,CC_SRV2,CT_MIZEN,WF_INDEP   /* "する未然形(せ)"*/},
{"#sxi2",POS_V,COS_NONE,SCOS_NONE,CC_SRV,CT_RENYOU,WF_INDEP   /* "する連用形(し)"*/},
{"#sxuru",POS_V,COS_NONE,SCOS_NONE,CC_SRV,CT_SYUSI,WF_INDEP   /* "する連用形(する)"*/},
{"#sxure",POS_V,COS_NONE,SCOS_NONE,CC_SRV,CT_KATEI,WF_INDEP   /* "する連用形(すれ)"*/},
{"#sxiro",POS_V,COS_NONE,SCOS_NONE,CC_SRV,CT_MEIREI,WF_INDEP   /*"する命令形(しろ)"*/},
{"#sxeyo",POS_V,COS_NONE,SCOS_NONE,CC_SRV2,CT_MEIREI,WF_INDEP   /*"する命令形(せよ)"*/},
{"#sxya",POS_V,COS_NONE,SCOS_NONE,CC_SRV2,CT_NONE,WF_INDEP   /* "する仮定形(すりゃ)"*/},
/**/
{"#T",POS_NOUN,COS_NONE,SCOS_T35,CC_NONE,CT_NONE,WF_INDEP   /* "名詞(語幹,格助接続)"*/},
/**/
{"#B5",POS_V,COS_NONE,SCOS_NONE,CC_B5,CT_HEAD,WF_INDEP /*"バ行五段"*/},
{"#B5r",POS_V,COS_NONE,SCOS_NONE,CC_B5,CT_HEAD,WF_INDEP|WF_MEISI /*"バ行五段(連用形名詞)"*/},
{"#C5r",POS_V,COS_NONE,SCOS_NONE,CC_C5,CT_HEAD,WF_INDEP|WF_MEISI /*"行く五段(連用形名詞)"*/},
{"#CJ",POS_CONJ,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* "接続詞・感動詞"*/},
{"#CN",POS_NOUN,COS_CN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* "地名"*/},
{"#CNPRE",POS_PRE,COS_CN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* "地名接頭語"*/},
{"#CNS",POS_NOUN,COS_CN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* "地名(接尾語つき)"*/},
{"#CNSUC1",POS_SUC,COS_CN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* "地名接尾語1"*/},
{"#CNSUC2",POS_SUC,COS_CN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP/* "地名接尾語2"(N/A)*/},
{"#D2KY",POS_D2KY,COS_SUFFIX,SCOS_A1,CC_A_KU,CT_HEAD,WF_INDEP /* "形容詞化接尾語(しづらい,がたい)"*/},
{"#yasui",POS_D2KY,COS_SUFFIX,SCOS_A1,CC_A_KU,CT_HEAD,WF_INDEP /* #D2KYと同じ*/},
{"#D2T16",POS_NOUN,COS_SUFFIX,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP|WF_AJV /* "形容動詞化接尾語(がち)"*/},
{"#D2T35",POS_NOUN,COS_SUFFIX,SCOS_T40,CC_NONE,CT_NONE,WF_INDEP /* "名詞化接尾語(っぱなし)"*/},
{"#F00",POS_AV,COS_NONE,SCOS_F0,CC_NONE,CT_NONE,WF_INDEP /* "副詞(と,たる,する,語幹)"*/},
{"#F01",POS_AV,COS_NONE,SCOS_F1,CC_NONE,CT_NONE,WF_INDEP /* "副詞(と,たる,する)"*/},
{"#F02",POS_AV,COS_NONE,SCOS_F2,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(と,たる,語幹)"*/},
{"#F03",POS_AV,COS_NONE,SCOS_F3,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(と,たる,)"*/},
{"#F04",POS_AV,COS_NONE,SCOS_F4,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(と,する,語幹)"*/},
{"#F05",POS_AV,COS_NONE,SCOS_F5,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(と,する)"*/},
{"#F06",POS_AV,COS_NONE,SCOS_F6,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(と,語幹)"*/},
{"#F07",POS_AV,COS_NONE,SCOS_F7,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(と)"(N/A)*/},
{"#F08",POS_AV,COS_NONE,SCOS_F8,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(たる,する,語幹)"(N/A)*/},
{"#F09",POS_AV,COS_NONE,SCOS_F9,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(たる,する)"*/},
{"#F10",POS_AV,COS_NONE,SCOS_F10,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(たる,語幹)"*/},
{"#F11",POS_AV,COS_NONE,SCOS_F11,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(たる)"*/},
{"#F12",POS_AV,COS_NONE,SCOS_F12,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(する,語幹)"*/},
{"#F13",POS_AV,COS_NONE,SCOS_F13,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(する)"*/},
{"#F14",POS_AV,COS_NONE,SCOS_F14,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(語幹)"*/},
{"#F15",POS_AV,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(未定義)"(N/A)*/},
{"#G5",POS_V,COS_NONE,SCOS_NONE,CC_G5,CT_HEAD,WF_INDEP    /* "ガ行五段"*/}, 
{"#G5r",POS_V,COS_NONE,SCOS_NONE,CC_G5,CT_HEAD,WF_INDEP|WF_MEISI   /* "ガ行五段(連用形名詞)"*/},
{"#JCN",POS_NOUN,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP   /* "人・地名"*/},
{"#JN",POS_NOUN,COS_JN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP    /* "人名"*/},
{"#JNM",POS_NOUN,COS_JN,SCOS_FSTNAME,CC_NONE,CT_NONE,WF_INDEP   /* "人名(名)"*/},
{"#JNMUC",POS_NOUN,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* "人名(名)接尾語"(N/A)*/},
{"#JNS",POS_NOUN,COS_JN,SCOS_FAMNAME,CC_NONE,CT_NONE,WF_INDEP   /* "人名(姓)"*/},
{"#JNSSUC",POS_SUC,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP/* "人名(姓)接尾語"(N/A)*/},
{"#JNSUC",POS_SUC,COS_JN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* "人名接尾語"*/},
{"#JS",POS_SUC,COS_NN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP    /* "助数詞"*/},
{"#JSSUC",POS_SUC,COS_NN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* "助数詞接続語"*/},
{"#K2T15",POS_NOUN,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* "名詞化接尾語(め)"(N/A)*/},
{"#K2T16",POS_NOUN,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* "名詞化接尾語(げ)"(N/A)*/},
{"#K2T35",POS_NOUN,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* "名詞化接尾語(さ)"(N/A)*/},
{"#K5",POS_V,COS_NONE,SCOS_NONE,CC_K5,CT_HEAD,WF_INDEP    /* "カ行五段"*/},
{"#K5r",POS_V,COS_NONE,SCOS_NONE,CC_K5,CT_HEAD,WF_INDEP|WF_MEISI   /* "カ行五段(連用形名詞)"*/},
{"#KJ",POS_TANKANJI,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP    /* "単漢字"*/},
{"#KK",POS_NOUN,COS_KK,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP    /* "団体名"*/},
{"#KN",POS_NOUN,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP    /* "形式名詞(あと,うち,etc)"(N/A)*/},
{"#KS",POS_V,COS_NONE,SCOS_NONE,CC_KS1,CT_HEAD,WF_INDEP    /* "上下一段"*/},
{"#KSr",POS_V,COS_NONE,SCOS_NONE,CC_KS1,CT_HEAD,WF_INDEP|WF_MEISI   /* "上下一段(連用形名詞)"*/},
{"#KY",POS_A,COS_NONE,SCOS_A0,CC_A_KU,CT_HEAD,WF_INDEP    /* "形容詞(ク活用)"*/},
{"#KYs",POS_A,COS_NONE,SCOS_A0,CC_A_SIKU,CT_HEAD,WF_INDEP    /* "形容詞(シク活用)"*/},
{"#KYE",POS_A,COS_NONE,SCOS_A0,CC_A_E,CT_HEAD,WF_INDEP   /* "形容詞(エ音便)"*/},
{"#KYI",POS_A,COS_NONE,SCOS_A0,CC_A_I,CT_HEAD,WF_INDEP   /* "形容詞(イ音便)"*/},
{"#KYU",POS_A,COS_NONE,SCOS_A0,CC_A_U,CT_HEAD,WF_INDEP   /* "形容詞(ウ音便)"*/},
{"#KYii",POS_A,COS_NONE,SCOS_A0,CC_A_ii,CT_HEAD,WF_INDEP    /* "形容詞「いい」"*/},
{"#KYn",POS_A,COS_NONE,SCOS_A0,CC_A_nai,CT_HEAD,WF_INDEP    /* "形容詞「ない」"*/},
{"#KYy",POS_A,COS_NONE,SCOS_A0,CC_A_yoi,CT_HEAD,WF_INDEP    /* "形容詞「よい」"*/},
/* ↓本当はこれらもク活用とシク活用で分ける必要があるが、不使用なので CC_A_KU で誤魔化す */
{"#KYme",POS_A,COS_NONE,SCOS_NONE,CC_A_KU,CT_HEAD,WF_INDEP  /* "形容詞(め終了形容動詞化)"(N/A)*/},
{"#KYmi",POS_A,COS_NONE,SCOS_NONE,CC_A_KU,CT_HEAD,WF_INDEP  /* "形容詞(み終了名詞化)"*/},
{"#KYmime",POS_A,COS_NONE,SCOS_NONE,CC_A_KU,CT_HEAD,WF_INDEP/* "形容詞(み・め終了形容動詞化)"(N/A)*/},
{"#KYna",POS_A,COS_NONE,SCOS_NONE,CC_A_KU,CT_HEAD,WF_INDEP  /* "形容詞(な終了連体詞化)"(N/A)*/},
{"#KYT",POS_A,COS_NONE,SCOS_NONE,CC_A_KU,CT_HEAD,WF_INDEP   /* "形容詞(名詞)"(N/A)*/},
/* ↑ここまで */
{"#L5",POS_V,COS_NONE,SCOS_NONE,CC_L5,CT_HEAD,WF_INDEP    /* "ラ行5段(命令形がイ)"*/},
{"#M5",POS_V,COS_NONE,SCOS_NONE,CC_M5,CT_HEAD,WF_INDEP    /* "マ行五段"*/},
{"#M5r",POS_V,COS_NONE,SCOS_NONE,CC_M5,CT_HEAD,WF_INDEP|WF_MEISI   /* "マ行五段(連用形名詞)"*/},
{"#N00",POS_NUMBER,COS_NN,SCOS_N10000,CC_NONE,CT_NONE,WF_INDEP   /* "数詞(x万,x億,x兆)"*/},
{"#N01",POS_NUMBER,COS_NN,SCOS_N1000,CC_NONE,CT_NONE,WF_INDEP   /* "数詞(千,二千,…,数千)"(N/A)*/},
{"#N02",POS_NUMBER,COS_NN,SCOS_N100,CC_NONE,CT_NONE,WF_INDEP   /* "数詞(百,二百,…,数百)"*/},
{"#N03",POS_NUMBER,COS_NN,SCOS_N10,CC_NONE,CT_NONE,WF_INDEP   /* "数詞(十,二十,…,数十)"*/},
{"#N2KYT",POS_NOUN,COS_NONE,SCOS_NONE,CC_A_KU,CT_HEAD,WF_INDEP /* "形容詞化接尾語(だかい,ばやい)"(N/A)*/},
{"#N2T10",POS_NOUN,COS_SUFFIX,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP|WF_AJV|WF_SV /* "名詞化接尾語(な,する,語幹,格助接続)"*/},
{"#N2T16",POS_AJV,COS_SUFFIX,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP|WF_AJV /* "副詞化接尾語(な,語幹,格助接続△)"*/},
{"#N2T17",POS_AJV,COS_SUFFIX,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP|WF_AJV /* "副詞化接尾語(な,語幹)"*/},
{"#N2T30",POS_N2T,COS_SUFFIX,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP|WF_SV /* "名詞化接尾語(する,語幹,格助接続)"*/},
{"#N2T35",POS_NOUN,COS_SUFFIX,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* "名詞化接尾語(語幹,格助接続)"*/},
{"#N5",POS_V,COS_NONE,SCOS_NONE,CC_N5,CT_HEAD,WF_INDEP    /* "ナ行五段"*/},
{"#N5r",POS_V,COS_NONE,SCOS_NONE,CC_N5,CT_HEAD,WF_INDEP|WF_MEISI  /* "ナ行五段(連用形名詞)"*/},
{"#ND2KY",POS_INVAL,COS_NONE,SCOS_NONE,CC_A_KU,CT_HEAD,WF_INDEP /* "形容詞化接尾語(がましい,づよい)"*/},
{"#NN",POS_NUMBER,COS_NN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP    /* "数詞(数,幾)"*/},
{"#NNPRE",POS_PRE,COS_NN,SCOS_NONE,CC_NONE,CT_NONE,WF_NONE /* "数詞接頭語"*/},
{"#OKX",POS_V,COS_NONE,SCOS_NONE,CC_SV,CT_NONE,WF_INDEP   /* "動詞丁寧表現語幹"*/},
{"#PRE",POS_PRE,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP   /* "一般名詞接頭語"*/},
{"#R5",POS_V,COS_NONE,SCOS_NONE,CC_R5,CT_HEAD,WF_INDEP    /* "ラ行五段"*/},
{"#R5r",POS_V,COS_NONE,SCOS_NONE,CC_R5,CT_HEAD,WF_INDEP|WF_MEISI   /* "ラ行五段(連用形名詞)"*/},
{"#RT",POS_ME,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP    /* "連体詞"*/},
{"#S5",POS_V,COS_NONE,SCOS_NONE,CC_S5,CT_HEAD,WF_INDEP    /* "サ行五段"*/},
{"#S5r",POS_V,COS_NONE,SCOS_NONE,CC_S5,CT_HEAD,WF_INDEP|WF_MEISI   /* "サ行五段(連用形名詞)"*/},
{"#SUC",POS_SUC,COS_SUFFIX,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP   /* "一般名詞接尾語"*/},
{"#SX",POS_V,COS_NONE,SCOS_NONE,CC_SV,CT_HEAD,WF_INDEP    /* "さ変動詞"*/},
{"#T00",POS_NOUN,COS_NONE,SCOS_T0,CC_NONE,CT_NONE,WF_INDEP|WF_AJV|WF_SV   /* "名詞(な,さ,する,語幹,格助接続)"*/},
{"#T01",POS_NOUN,COS_NONE,SCOS_T1,CC_NONE,CT_NONE,WF_INDEP|WF_AJV|WF_SV   /* "名詞(な,さ,する,語幹,格助接続△)(N/A)"*/},
{"#T02",POS_NOUN,COS_NONE,SCOS_T2,CC_NONE,CT_NONE,WF_INDEP|WF_AJV|WF_SV   /* "名詞(な,さ,する,語幹)"*/},
{"#T03",POS_NOUN,COS_NONE,SCOS_T3,CC_NONE,CT_NONE,WF_INDEP|WF_AJV|WF_SV   /* "名詞(な,さ,する,格助接続)"*/},
{"#T04",POS_NOUN,COS_NONE,SCOS_T4,CC_NONE,CT_NONE,WF_INDEP|WF_AJV|WF_SV   /* "名詞(な,さ,する)"(N/A)*/},
{"#T05",POS_NOUN,COS_NONE,SCOS_T5,CC_NONE,CT_NONE,WF_INDEP|WF_AJV   /* "名詞(な,さ,語幹,格助接続)"*/},
{"#T06",POS_NOUN,COS_NONE,SCOS_T6,CC_NONE,CT_NONE,WF_INDEP|WF_AJV   /* "名詞(な,さ,語幹,格助接続△)"*/},
{"#T07",POS_NOUN,COS_NONE,SCOS_T7,CC_NONE,CT_NONE,WF_INDEP|WF_AJV   /* "副詞(な,さ,語幹)"*/},
{"#T08",POS_NOUN,COS_NONE,SCOS_T8,CC_NONE,CT_NONE,WF_INDEP|WF_AJV   /* "名詞(な,さ,格助接続△)"*/},
{"#T09",POS_NOUN,COS_NONE,SCOS_T9,CC_NONE,CT_NONE,WF_INDEP|WF_AJV   /* "名詞(な,さ)"(N/A)*/},
{"#T10",POS_NOUN,COS_NONE,SCOS_T10,CC_NONE,CT_NONE,WF_INDEP|WF_AJV|WF_SV   /* "名詞(な,する,語幹,格助接続)"*/},
{"#T11",POS_NOUN,COS_NONE,SCOS_T11,CC_NONE,CT_NONE,WF_INDEP|WF_AJV|WF_SV   /* "名詞(な,する,語幹,格助接続△)"*/},
{"#T12",POS_NOUN,COS_NONE,SCOS_T12,CC_NONE,CT_NONE,WF_INDEP|WF_AJV|WF_SV   /* "名詞(な,する,語幹)"*/},
{"#T13",POS_NOUN,COS_NONE,SCOS_T13,CC_NONE,CT_NONE,WF_INDEP|WF_AJV|WF_SV   /* "名詞(な,する,格助接続△)"*/},
{"#T14",POS_NOUN,COS_NONE,SCOS_T14,CC_NONE,CT_NONE,WF_INDEP|WF_AJV|WF_SV   /* "名詞(な,する)"(N/A)*/},
{"#T15",POS_NOUN,COS_NONE,SCOS_T15,CC_NONE,CT_NONE,WF_INDEP|WF_AJV  /* "名詞・副詞(な,語幹,格助接続)"*/},
{"#T16",POS_NOUN,COS_NONE,SCOS_T16,CC_NONE,CT_NONE,WF_INDEP|WF_AJV   /* "副詞(な,語幹,格助接続△)"*/},
{"#T17",POS_NOUN,COS_NONE,SCOS_T17,CC_NONE,CT_NONE,WF_INDEP|WF_AJV   /* "副詞(な,語幹)"*/},
{"#T18",POS_NOUN,COS_NONE,SCOS_T18,CC_NONE,CT_NONE,WF_INDEP|WF_AJV   /* "名詞(な,格助接続△)"*/},
{"#T19",POS_NOUN,COS_NONE,SCOS_T19,CC_NONE,CT_NONE,WF_INDEP|WF_AJV   /* "名詞(な)"*/},
{"#T20",POS_NOUN,COS_NONE,SCOS_T20,CC_NONE,CT_NONE,WF_INDEP|WF_SV   /* "名詞(さ,する,語幹,格助接続)"(N/A)*/},
{"#T21",POS_NOUN,COS_NONE,SCOS_T21,CC_NONE,CT_NONE,WF_INDEP|WF_SV   /* "名詞(さ,する,語幹,格助接続△)"(N/A)*/},
{"#T22",POS_NOUN,COS_NONE,SCOS_T22,CC_NONE,CT_NONE,WF_INDEP|WF_SV   /* "名詞(さ,する,語幹)"(N/A)*/},
{"#T23",POS_NOUN,COS_NONE,SCOS_T23,CC_NONE,CT_NONE,WF_INDEP|WF_SV   /* "名詞(さ,する,格助接続△)"(N/A)*/},
{"#T24",POS_NOUN,COS_NONE,SCOS_T24,CC_NONE,CT_NONE,WF_INDEP|WF_SV   /* "名詞(さ,する)"(N/A)*/},
{"#T25",POS_NOUN,COS_NONE,SCOS_T25,CC_NONE,CT_NONE,WF_INDEP   /* "名詞(さ,語幹,格助接続)"(N/A)*/},
{"#T26",POS_NOUN,COS_NONE,SCOS_T26,CC_NONE,CT_NONE,WF_INDEP   /* "名詞(さ,語幹,格助接続△)"(N/A)*/},
{"#T27",POS_NOUN,COS_NONE,SCOS_T27,CC_NONE,CT_NONE,WF_INDEP   /* "名詞(さ,語幹)"(N/A)*/},
{"#T28",POS_NOUN,COS_NONE,SCOS_T28,CC_NONE,CT_NONE,WF_INDEP   /* "名詞(さ,格助接続△)"(N/A)*/},
{"#T29",POS_NOUN,COS_NONE,SCOS_T29,CC_NONE,CT_NONE,WF_INDEP   /* "名詞(さ)"(N/A)*/},
{"#T30",POS_NOUN,COS_NONE,SCOS_T30,CC_NONE,CT_NONE,WF_INDEP|WF_SV   /* "名詞(する,語幹,格助接続)"*/},
{"#T31",POS_NOUN,COS_NONE,SCOS_T31,CC_NONE,CT_NONE,WF_INDEP|WF_SV   /* "副詞(する,語幹,格助接続△)"*/},
{"#T32",POS_NOUN,COS_NONE,SCOS_T32,CC_NONE,CT_NONE,WF_INDEP|WF_SV   /* "名詞(する,語幹)"(N/A)*/},
{"#T33",POS_NOUN,COS_NONE,SCOS_T33,CC_NONE,CT_NONE,WF_INDEP|WF_SV   /* "名詞(する,格助接続△)"(N/A)*/},
{"#T34",POS_NOUN,COS_NONE,SCOS_T34,CC_NONE,CT_NONE,WF_INDEP|WF_SV   /* "名詞(する)"(N/A)*/},
{"#T35",POS_NOUN,COS_NONE,SCOS_T35,CC_NONE,CT_NONE,WF_INDEP   /* "名詞(語幹,格助接続)"*/},
{"#T36",POS_NOUN,COS_NONE,SCOS_T36,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(語幹,格助接続△)"*/},
{"#T37",POS_NOUN,COS_NONE,SCOS_T37,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(語幹)"(N/A)*/},
{"#T38",POS_NOUN,COS_NONE,SCOS_T38,CC_NONE,CT_NONE,WF_INDEP   /* "副詞(語幹)"(N/A)*/},
{"#T39",POS_NOUN,COS_NONE,SCOS_T39,CC_NONE,CT_NONE,WF_INDEP   /* "名詞副詞(語幹)"(N/A)*/},
{"#T5",POS_V,COS_NONE,SCOS_NONE,CC_T5,CT_HEAD,WF_INDEP    /* "タ行五段"*/},
{"#T5r",POS_V,COS_NONE,SCOS_NONE,CC_T5,CT_HEAD,WF_INDEP|WF_MEISI   /* "タ行五段(連用形名詞)"*/},
{"#U5",POS_V,COS_NONE,SCOS_NONE,CC_U5,CT_HEAD,WF_INDEP    /* "乞う五段"*/},
{"#U5r",POS_V,COS_NONE,SCOS_NONE,CC_U5,CT_HEAD,WF_INDEP|WF_MEISI   /* "乞う五段(連用形名詞)"*/},
{"#W5",POS_V,COS_NONE,SCOS_NONE,CC_W5,CT_HEAD,WF_INDEP    /* "ワ行五段"*/},
{"#W5r",POS_V,COS_NONE,SCOS_NONE,CC_W5,CT_HEAD,WF_INDEP|WF_MEISI   /* "ワ行五段(連用形名詞)"*/},
{"#ZX",POS_V,COS_NONE,SCOS_NONE,CC_ZV,CT_HEAD,WF_INDEP    /* "さ変動詞"*/},
{"#aru",POS_V,COS_NONE,SCOS_NONE,CC_RV,CT_HEAD,WF_INDEP|WF_MEISI   /* "ある"*/},
  /* 独自拡張 */
{"#arazu",POS_V,COS_NONE,SCOS_NONE,CC_RZ,CT_HEAD,WF_INDEP /* "連語「非ず」"*/},
{"#NONE",POS_INVAL,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_NONE},
{"#N04",POS_NUMBER,COS_NN,SCOS_N1,CC_NONE,CT_NONE,WF_NONE},/*いち、に、さん…*/
{"#N05",POS_NUMBER,COS_NN,SCOS_N100,CC_NONE,CT_NONE,WF_NONE},/*ひゃく、にひゃく*/
{"#SVSUC",POS_SUC,COS_SVSUFFIX,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* サ変接尾語*/},
{"#OPEN",POS_OPEN,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* 開き括弧 */},
{"#CLOSE",POS_CLOSE,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP /* 閉じ括弧 */},
{0,0,0,0,0,0,0},
