/* POS(Part of Speech) table */
{"名詞",POS_NOUN,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"名詞0",POS_NOUN,COS_NONE,SCOS_T0,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞1",POS_NOUN,COS_NONE,SCOS_T1,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞2",POS_NOUN,COS_NONE,SCOS_T2,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞3",POS_NOUN,COS_NONE,SCOS_T3,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞4",POS_NOUN,COS_NONE,SCOS_T4,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞5",POS_NOUN,COS_NONE,SCOS_T5,CC_NONE,CT_NONE,WF_INDEP},
{"名詞6",POS_NOUN,COS_NONE,SCOS_T6,CC_NONE,CT_NONE,WF_INDEP},
{"名詞7",POS_NOUN,COS_NONE,SCOS_T7,CC_NONE,CT_NONE,WF_INDEP},
{"名詞8",POS_NOUN,COS_NONE,SCOS_T8,CC_NONE,CT_NONE,WF_INDEP},
{"名詞9",POS_NOUN,COS_NONE,SCOS_T9,CC_NONE,CT_NONE,WF_INDEP},
{"名詞10",POS_NOUN,COS_NONE,SCOS_T10,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞11",POS_NOUN,COS_NONE,SCOS_T11,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞12",POS_NOUN,COS_NONE,SCOS_T12,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞13",POS_NOUN,COS_NONE,SCOS_T13,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞14",POS_NOUN,COS_NONE,SCOS_T14,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞15",POS_NOUN,COS_NONE,SCOS_T15,CC_NONE,CT_NONE,WF_INDEP},
{"名詞16",POS_NOUN,COS_NONE,SCOS_T16,CC_NONE,CT_NONE,WF_INDEP},
{"名詞17",POS_NOUN,COS_NONE,SCOS_T17,CC_NONE,CT_NONE,WF_INDEP},
{"名詞18",POS_NOUN,COS_NONE,SCOS_T18,CC_NONE,CT_NONE,WF_INDEP},
{"名詞19",POS_NOUN,COS_NONE,SCOS_T19,CC_NONE,CT_NONE,WF_INDEP},
{"名詞20",POS_NOUN,COS_NONE,SCOS_T20,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞21",POS_NOUN,COS_NONE,SCOS_T21,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞22",POS_NOUN,COS_NONE,SCOS_T22,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞23",POS_NOUN,COS_NONE,SCOS_T23,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞24",POS_NOUN,COS_NONE,SCOS_T24,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞25",POS_NOUN,COS_NONE,SCOS_T25,CC_NONE,CT_NONE,WF_INDEP},
{"名詞26",POS_NOUN,COS_NONE,SCOS_T26,CC_NONE,CT_NONE,WF_INDEP},
{"名詞27",POS_NOUN,COS_NONE,SCOS_T27,CC_NONE,CT_NONE,WF_INDEP},
{"名詞28",POS_NOUN,COS_NONE,SCOS_T28,CC_NONE,CT_NONE,WF_INDEP},
{"名詞29",POS_NOUN,COS_NONE,SCOS_T29,CC_NONE,CT_NONE,WF_INDEP},
{"名詞30",POS_NOUN,COS_NONE,SCOS_T30,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞31",POS_NOUN,COS_NONE,SCOS_T31,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞32",POS_NOUN,COS_NONE,SCOS_T32,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞33",POS_NOUN,COS_NONE,SCOS_T33,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞34",POS_NOUN,COS_NONE,SCOS_T34,CC_NONE,CT_NONE,WF_INDEP|WF_SV},
{"名詞35",POS_NOUN,COS_NONE,SCOS_T35,CC_NONE,CT_NONE,WF_INDEP},
{"名詞36",POS_NOUN,COS_NONE,SCOS_T36,CC_NONE,CT_NONE,WF_INDEP},
{"名詞37",POS_NOUN,COS_NONE,SCOS_T37,CC_NONE,CT_NONE,WF_INDEP},
{"名詞38",POS_NOUN,COS_NONE,SCOS_T38,CC_NONE,CT_NONE,WF_INDEP},
{"名詞39",POS_NOUN,COS_NONE,SCOS_T39,CC_NONE,CT_NONE,WF_INDEP},
{"名詞化接尾語",POS_NOUN,COS_SUFFIX,SCOS_T40,CC_NONE,CT_NONE,WF_INDEP},
{"数詞",POS_NUMBER,COS_NN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"数詞1",POS_NUMBER,COS_NN,SCOS_N1,CC_NONE,CT_NONE,WF_INDEP},
{"数詞10",POS_NUMBER,COS_NN,SCOS_N10,CC_NONE,CT_NONE,WF_INDEP},
{"数詞100",POS_NUMBER,COS_NN,SCOS_N100,CC_NONE,CT_NONE,WF_INDEP},
{"数詞1000",POS_NUMBER,COS_NN,SCOS_N1000,CC_NONE,CT_NONE,WF_INDEP},
{"数詞10000",POS_NUMBER,COS_NN,SCOS_N10000,CC_NONE,CT_NONE,WF_INDEP},
{"人名",POS_NOUN,COS_JN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"地名",POS_NOUN,COS_CN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"団体名",POS_NOUN,COS_KK,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"開き括弧",POS_OPEN,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"閉じ括弧",POS_CLOSE,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"名詞接頭辞",POS_PRE,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"人名接尾辞",POS_SUC,COS_JN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"名詞接尾辞",POS_NOUN,COS_SUFFIX,SCOS_NONE,CC_NONE,CT_NONE,WF_NONE},
{"数接頭辞",POS_PRE,COS_NN,SCOS_NONE,CC_NONE,CT_NONE,WF_NONE},
{"数接尾辞",POS_SUC,COS_NN,SCOS_NONE,CC_NONE,CT_NONE,WF_NONE},
{"地名接頭辞",POS_PRE,COS_CN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"地名接尾辞",POS_SUC,COS_CN,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"サ変接尾辞",POS_SUC,COS_SVSUFFIX,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"助詞",POS_PRT,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_NONE},
{"副詞",POS_AV,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"副詞0",POS_AV,COS_NONE,SCOS_F0,CC_NONE,CT_NONE,WF_INDEP},
{"副詞1",POS_AV,COS_NONE,SCOS_F1,CC_NONE,CT_NONE,WF_INDEP},
{"副詞2",POS_AV,COS_NONE,SCOS_F2,CC_NONE,CT_NONE,WF_INDEP},
{"副詞3",POS_AV,COS_NONE,SCOS_F3,CC_NONE,CT_NONE,WF_INDEP},
{"副詞4",POS_AV,COS_NONE,SCOS_F4,CC_NONE,CT_NONE,WF_INDEP},
{"副詞5",POS_AV,COS_NONE,SCOS_F5,CC_NONE,CT_NONE,WF_INDEP},
{"副詞6",POS_AV,COS_NONE,SCOS_F6,CC_NONE,CT_NONE,WF_INDEP},
{"副詞7",POS_AV,COS_NONE,SCOS_F7,CC_NONE,CT_NONE,WF_INDEP},
{"副詞8",POS_AV,COS_NONE,SCOS_F8,CC_NONE,CT_NONE,WF_INDEP},
{"副詞9",POS_AV,COS_NONE,SCOS_F9,CC_NONE,CT_NONE,WF_INDEP},
{"副詞10",POS_AV,COS_NONE,SCOS_F10,CC_NONE,CT_NONE,WF_INDEP},
{"副詞11",POS_AV,COS_NONE,SCOS_F11,CC_NONE,CT_NONE,WF_INDEP},
{"副詞12",POS_AV,COS_NONE,SCOS_F12,CC_NONE,CT_NONE,WF_INDEP},
{"副詞13",POS_AV,COS_NONE,SCOS_F13,CC_NONE,CT_NONE,WF_INDEP},
{"副詞14",POS_AV,COS_NONE,SCOS_F14,CC_NONE,CT_NONE,WF_INDEP},
{"副詞語幹",POS_AV,COS_NONE,SCOS_NONE,CC_NONE,CT_HEAD,WF_NONE},
{"動詞",POS_V,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_NONE,CT_HEAD,WF_INDEP},
{"接続詞",POS_CONJ,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_NONE},
  /**/
{"動詞未然形",POS_V,COS_NONE,SCOS_NONE,CC_NONE,CT_MIZEN,WF_INDEP},
  /**/
{"動詞連用形",POS_V,COS_NONE,SCOS_NONE,CC_NONE,CT_RENYOU,WF_INDEP},
  /**/
{"動詞終止形",POS_V,COS_NONE,SCOS_NONE,CC_NONE,CT_SYUSI,WF_INDEP},
  /**/
{"動詞連体形",POS_V,COS_NONE,SCOS_NONE,CC_NONE,CT_RENTAI,WF_INDEP},
  /**/
{"動詞仮定形",POS_V,COS_NONE,SCOS_NONE,CC_NONE,CT_KATEI,WF_INDEP},
  /**/
{"動詞命令形",POS_V,COS_NONE,SCOS_NONE,CC_NONE,CT_MEIREI,WF_INDEP},
  /**/
{"カ行5段活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_K5,CT_HEAD,WF_INDEP},
{"カ行C5段活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_C5,CT_HEAD,WF_INDEP},
{"ガ行5段活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_G5,CT_HEAD,WF_INDEP},
{"サ行5段活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_S5,CT_HEAD,WF_INDEP},
{"タ行5段活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_T5,CT_HEAD,WF_INDEP},
{"ナ行5段活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_N5,CT_HEAD,WF_INDEP},
{"マ行5段活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_M5,CT_HEAD,WF_INDEP},
{"バ行5段活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_B5,CT_HEAD,WF_INDEP},
{"ラ行5段活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_R5,CT_HEAD,WF_INDEP},
{"ラ行L5段活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_L5,CT_HEAD,WF_INDEP},
{"ワ行5段活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_W5,CT_HEAD,WF_INDEP},
{"ワ行U5段活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_U5,CT_HEAD,WF_INDEP},
{"上下一段活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_KS1,CT_HEAD,WF_INDEP},
{"カ行5段活用動詞名詞化語幹",POS_V,COS_NONE,SCOS_NONE,CC_K5,CT_MEISIKA,WF_INDEP},
{"カ行C5段活用動詞名詞化語幹",POS_V,COS_NONE,SCOS_NONE,CC_C5,CT_MEISIKA,WF_INDEP},
{"ガ行5段活用動詞名詞化語幹",POS_V,COS_NONE,SCOS_NONE,CC_G5,CT_MEISIKA,WF_INDEP},
{"サ行5段活用動詞名詞化語幹",POS_V,COS_NONE,SCOS_NONE,CC_S5,CT_MEISIKA,WF_INDEP},
{"タ行5段活用動詞名詞化語幹",POS_V,COS_NONE,SCOS_NONE,CC_T5,CT_MEISIKA,WF_INDEP},
{"ナ行5段活用動詞名詞化語幹",POS_V,COS_NONE,SCOS_NONE,CC_N5,CT_MEISIKA,WF_INDEP},
{"マ行5段活用動詞名詞化語幹",POS_V,COS_NONE,SCOS_NONE,CC_M5,CT_MEISIKA,WF_INDEP},
{"バ行5段活用動詞名詞化語幹",POS_V,COS_NONE,SCOS_NONE,CC_B5,CT_MEISIKA,WF_INDEP},
{"ラ行5段活用動詞名詞化語幹",POS_V,COS_NONE,SCOS_NONE,CC_R5,CT_MEISIKA,WF_INDEP},
{"ラ行L5段活用動詞名詞化語幹",POS_V,COS_NONE,SCOS_NONE,CC_L5,CT_MEISIKA,WF_INDEP},
{"ワ行5段活用動詞名詞化語幹",POS_V,COS_NONE,SCOS_NONE,CC_W5,CT_MEISIKA,WF_INDEP},
{"ワ行U5段活用動詞名詞化語幹",POS_V,COS_NONE,SCOS_NONE,CC_U5,CT_MEISIKA,WF_INDEP},
{"上下一段活用動詞名詞化語幹",POS_V,COS_NONE,SCOS_NONE,CC_KS1,CT_MEISIKA,WF_INDEP},
  /**/
{"ラ変活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_RV,CT_HEAD,WF_INDEP},
{"カ変活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_KV,CT_HEAD,WF_INDEP},
{"サ変活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_SV,CT_HEAD,WF_INDEP},
{"ザ変活用動詞語幹",POS_V,COS_NONE,SCOS_NONE,CC_ZV,CT_HEAD,WF_INDEP},
  /**/
{"連語「非ず」語幹",POS_V,COS_NONE,SCOS_NONE,CC_RZ,CT_HEAD,WF_INDEP},
  /**/
{"カ変活用動詞未然形",POS_V,COS_NONE,SCOS_NONE,CC_KV,CT_MIZEN,WF_INDEP},
{"カ変活用動詞連用形",POS_V,COS_NONE,SCOS_NONE,CC_KV,CT_RENYOU,WF_INDEP},
{"カ変活用動詞終止形",POS_V,COS_NONE,SCOS_NONE,CC_KV,CT_SYUSI,WF_INDEP},
{"カ変活用動詞終止形2",POS_V,COS_NONE,SCOS_NONE,CC_KV2,CT_SYUSI,WF_INDEP},
{"カ変活用動詞仮定形",POS_V,COS_NONE,SCOS_NONE,CC_KV,CT_KATEI,WF_INDEP},
{"カ変活用動詞仮定形2",POS_V,COS_NONE,SCOS_NONE,CC_KV2,CT_NONE,WF_INDEP},
{"カ変活用動詞命令形",POS_V,COS_NONE,SCOS_NONE,CC_KV,CT_MEIREI,WF_INDEP},
  /**/
{"する未然形「し」",POS_V,COS_NONE,SCOS_NONE,CC_SRV,CT_MIZEN,WF_INDEP},
{"する未然形「せ」",POS_V,COS_NONE,SCOS_NONE,CC_SRV2,CT_MIZEN,WF_INDEP},
{"する連用形「し」",POS_V,COS_NONE,SCOS_NONE,CC_SRV,CT_RENYOU,WF_INDEP},
{"する終止形「する」",POS_V,COS_NONE,SCOS_NONE,CC_SRV,CT_SYUSI,WF_INDEP},
{"する仮定形「すれ」",POS_V,COS_NONE,SCOS_NONE,CC_SRV,CT_KATEI,WF_INDEP},
{"する仮定形「すりゃ」",POS_V,COS_NONE,SCOS_NONE,CC_SRV2,CT_NONE,WF_INDEP},
{"する命令形「しろ」",POS_V,COS_NONE,SCOS_NONE,CC_SRV,CT_MEIREI,WF_INDEP},
{"する命令形「せよ」",POS_V,COS_NONE,SCOS_NONE,CC_SRV2,CT_MEIREI,WF_INDEP},
  /**/
{"形容詞ク語幹",POS_A,COS_NONE,SCOS_A0,CC_A_KU,CT_HEAD,WF_INDEP},
{"形容詞シク語幹",POS_A,COS_NONE,SCOS_A0,CC_A_SIKU,CT_HEAD,WF_INDEP},
{"形容詞語幹エ音便",POS_A,COS_NONE,SCOS_A0,CC_A_E,CT_HEAD,WF_INDEP},
{"形容詞語幹イ音便",POS_A,COS_NONE,SCOS_A0,CC_A_I,CT_HEAD,WF_INDEP},
{"形容詞ウ音便",POS_A,COS_NONE,SCOS_A0,CC_A_U,CT_HEAD,WF_INDEP},
{"形容詞「いい」語幹",POS_A,COS_NONE,SCOS_A0,CC_A_ii,CT_HEAD,WF_INDEP},
{"形容詞「ない」語幹",POS_A,COS_NONE,SCOS_A0,CC_A_nai,CT_HEAD,WF_INDEP},
{"形容詞「よい」語幹",POS_A,COS_NONE,SCOS_A0,CC_A_yoi,CT_HEAD,WF_INDEP},
{"形容詞",POS_A,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_NONE},
{"形容詞化接尾語",POS_D2KY,COS_NONE,SCOS_A1,CC_NONE,CT_HEAD,WF_INDEP},
{"形容詞未然形",POS_A,COS_NONE,SCOS_NONE,CC_NONE,CT_MIZEN,WF_NONE},
{"形容詞連用形",POS_A,COS_NONE,SCOS_NONE,CC_NONE,CT_RENYOU,WF_NONE},
{"形容詞終止形",POS_A,COS_NONE,SCOS_NONE,CC_NONE,CT_SYUSI,WF_NONE},
{"形容詞連体形",POS_A,COS_NONE,SCOS_NONE,CC_NONE,CT_RENTAI,WF_NONE},
{"形容詞仮定形",POS_A,COS_NONE,SCOS_NONE,CC_NONE,CT_KATEI,WF_NONE},
{"形容詞語幹",POS_A,COS_NONE,SCOS_NONE,CC_NONE,CT_HEAD,WF_NONE},
  /**/
{"形容動詞未然形",POS_AJV,COS_NONE,SCOS_NONE,CC_NONE,CT_MIZEN,WF_NONE},
{"形容動詞連用形",POS_AJV,COS_NONE,SCOS_NONE,CC_NONE,CT_RENYOU,WF_NONE},
{"形容動詞終止形",POS_AJV,COS_NONE,SCOS_NONE,CC_NONE,CT_SYUSI,WF_NONE},
{"形容動詞連体形",POS_AJV,COS_NONE,SCOS_NONE,CC_NONE,CT_RENTAI,WF_NONE},
{"形容動詞仮定形",POS_AJV,COS_NONE,SCOS_NONE,CC_NONE,CT_KATEI,WF_NONE},
{"形容動詞原形",POS_AJV,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_NONE},/*形容動詞の原形*/
{"形容動詞語幹",POS_AJV,COS_NONE,SCOS_NONE,CC_NONE,CT_HEAD,WF_NONE},
{"形容動詞化接尾語",POS_NOUN,COS_SUFFIX,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP|WF_AJV},
  /**/
{"単漢字",POS_TANKANJI,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_NONE},
{"連体詞",POS_ME,COS_NONE,SCOS_NONE,CC_NONE,CT_NONE,WF_INDEP},
{"動詞丁寧表現語幹",POS_V,COS_NONE,SCOS_NONE,CC_SV,CT_NONE,WF_INDEP},
{0,0,0,0,0,0,0},
